/*
 * main_200915162.c
 * 
 * Copyright 2012 Jose <jose@Jose>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 * 
 */


/* 
 * Universidad de San Carlos de Guatemala
 * Facultad de Ingenieria
 * Escuela de Ciencias y Sistemas
 * Manejo e implementacion de archivos
 * Seccion A+
 * Laboratorio
 * Proyecto 1
 * 05/09/2012 13:23 hrs
 */
 
//---------------------Area de librerias--------------------------
 
#include <stdio.h>
//atoi
#include <stdlib.h>
//directorios
#include <dirent.h>
//crear directorios
#include <sys/stat.h>
//comparacion de cadenas
#include <string.h>
//time
#include <time.h>

//-------------------------------------------------------------------------

//---------------------Area de estructuras--------------------------

//guarda la ruta de los discos duros del sistema

struct struct_disco{
	char nombre[52];
	char tamano[9];
	char particiones[9];
	char puntero[9];//direccion al mbr
};

struct struct_mbr{
	char mbr_byte_particion[10];//Contiene el byte donde inicia la partición.
	char mbr_byte_particion_desactivada[10];//Contiene el byte donde inicia la partición.
	char mbr_tipo_sistema_archivos[7];//Contiene el tipo de sistema de archivos.
	char mbr_tipo_particion[12];//Contiene el tipo de partición.
	char mbr_particion_activa[4];//Indica si la partición es la activa, está será la por defecto que iniciará para realizar operaciones sobre el sistema de archivos.
	char mbr_size_bytes[10];//Contiene el tamaño en bytes del sistema de archivos.
};

struct struct_log{
	char log_activo[4];//1=activo, 0=desactivo
	char log_tipo_operacion[53];//El tipo de operación a realizarse
	char log_tipo[4];//Si es archivo (0), sies directorio(1)
	char log_nombre[643];//Nombre archivo o directorio(path completo)
	char log_contenido[515];//Si hay datos contenidos(512)
	char log_fecha[19];//Fecha de transacción
};

//estructuras para EXT3

struct struct_superbloque{
	char sb_numero_inodos[9];//Cantidad de i-nodos que tiene el sistema de archivos.
	char sb_numero_bloques[9];//Cantidad de bloques de datos que tiene el sistema de archivos.
	char sb_numero_log[9];//Cantidad de logs que tiene el sistema de archivos.
	char sb_tamanio_bloque[4];//El tamaño dado a cada bloque.
	char sb_numero_magico[7];//Firma del disco duro
	char sb_bloques_freee[9];//Cantidad de bloques de datos libres.
	char sb_inodos_free[9];//Cantidad de i-nodos libres.
	char sb_log_free[9];//Cantidad de logs libres.
	char sb_date_creacion[19];//fecha de creacion del sistema dd/mm/yyyy hh:mm
	char sb_mount_time[19];//Contendrá la última fecha de montaje (dd/mm/yyyy hh:mm). Es decir la última vez que se montóel sistema en lectura/escritura como el time_t
	char sb_write_time[19];//Indicara la últimafecha y hora en la cual se desmonto el sistema habiéndolo montado como lectura/escritura.
	char sb_mount_count[9];//Cantidad de veces que se montó el sistema.
	char sb_ap_bitacora[9];//Apuntador al inicio del bloque de la bitácora.
	char sb_first_inodo[9];//Este será un apuntador al inodo del directorio raíz
	char sb_first_bloque[9];//Este será un apuntador al primer bloque de datos.
	char sb_fist_free_bitmapinodo[9];//Primer bit libre en el bitmap de i-nodo
	char sb_first_free_bitmapbloque[9];// Primer bit libre en el bitmap de bloque de datos.
	char sb_first_free_log[9];//Primer estructura libre en la bitacora
};

//mapas de bits son definidos de la forma char map[cantidad]; donde cantidad es un dato dinamico

struct struct_inodo{
	char Llave[9];//Indicara el id del inodo
	char i_tipo[6];//tipo: file o dir
	char i_date_mod[19];//Fecha y hora del último cambio al contenido de esta estructura
	char i_tam_archivo[9];//Indicar el tamaño del archivo(en bytes)
	char i_asig_bloques[9];//Numero de bloques asignados
	char i_time_last_access[18];//Tiempo de último acceso. Es decir la fecha en la cual se accedió a este inodo para obtener información de sus carpetas o archivos hijos.
	char i_ctime[18];//Fecha y hora de creación del inodo
	char i_block1[9];//Bloque directo 1
	char i_block2[9];//Bloque directo 2
	char i_block3[9];//Bloque directo 3
	char i_block4[9];//Bloque directo 4
	char i_Iblock[9];//Bloque indirecto
};

//inodo con ubicacion leida
struct struct_inodo_ubicacion{
	struct struct_inodo inodo;
	char ubicacion[642];
};

//bloque
struct struct_bloque{
	char data[64]; //tamaño de 64 bytes
	char estado[3]; //vacio=0, ocupado=1
};

//Estructura para el sistema de archivos FAT

struct struct_boot{
	char b_nombre_unidad[52];//Es la raíz principal de donde se derivan todos los árboles. C:
	char b_usuario[52];//Usuario para ingresar al Sistema
	char b_password[52];//Password para ingresar al Sistema
	char b_tamano[9];//Tamaño en bytes del sistema de archivos
	char b_tablas_count[9];//Cantidad de bloque de datos
	char b_bloques_count[9];//Cantidad de bloque de datos
	char b_log_count[9];//Cantidad de log de datos
	char b_next_tabla_free[9];//siguiente tabla libre
	char b_next_bloque_free[9];//siguiente bloque libre
	char b_next_log_free[9];//siguiente log libre
	char b_tablas_free[9];//Cantidad de tablas libres
	char b_bloques_free[9];//Cantidad de bloques de datos libres
	char b_log_free[9];//Cantidad de estructuras de log libres.
	char b_date_creacion[18];//Fecha de creación del sistema el formato de fecha: dd/mm/yyyy hh:mm
	char b_date_ultimo_montaje[18];//Última fecha de montaje el formato de fecha: dd/mm/yyyy hh:mm
	char b_montajes_count[9];//Contador de montajes del sistema de archivos LWH
	char b_ap_bloque_tabla_indexada[9];//Apuntador al inicio del bloque de la tabla indexada alfabéticamente.
	char b_ap_bloque_datos[9];//Apuntador al inicio del bloque de datos
	char b_ap_log[9];//Apuntador al inicio del bloque de bitácora.
	char b_size_struct_tabla_indexada[9];//Tamaño de una estructura en el árbol de nodo fichero
	char b_size_struct_bloque_dato[9];//Tamaño de la estructura en el bloque de grupos
	char b_size_struct_bitacora[9];//Tamaño de la estructura en la bitácora
};

struct struct_tabla{
	char disponible[3]; //si esta libre =0, =1 ocupado
	char lista_nombre[52];//Contiene el nombre de la carpeta o archivo
	char lista_tipo[6];//Para identificar si es una carpeta o archivo
	char lista_nombre_padre[52];//Indica el nombre de la carpeta padre
	char lista_ap_directo_bloque[9];//Apuntador al byte o al número de la estructura en donde inicia el bloque de datos que contiene la información del archivo. Null si es carpeta.
	char lista_nivel[3];//Número indicando el nivel de jerarquía, hasta un máximo de 4 niveles.
	char lista_fecha_creacion[18];//Fecha de creación dela carpeta oarchivoel formato de fecha: dd/mm/yyyy hh:mm
	char lista_fecha_modificacion[18];//Fecha de modificación dela carpeta o archivoel formato de fecha: dd/mm/yyyy hh:mm
};

struct struct_datos{
	char disponible[3]; //si esta libre =0, =1 ocupado
	char bd_data[51];//Contiene la información del archivo.51 Caracteres, 50caracteres + 1 de finalización
	char bd_numero[9];//Número de bloque de datos
	char bd_ap_directo_siguiente[9];//Apuntador Número de bloque siguiente que contiene información o número de byte.
};

//------------------------------------------------------------------

//---------------------Area de variables globales--------------------------

//guarda la ruta de los discos duros del sistema
char sistema[8]="sistema/";
char sistema_reporte[17]="reporte/";
//direccion del disco actual
char directorio[58];
char directorio_reporte[640];
//bit utilizado para guardar 0's
char buffer[1];
//contador de fors
int ifor=0;
//variable directorio global
DIR *d;
//para listar discos
struct dirent *di;
//fecha actual
char fecha[16];
//FAT login (0= no ha iniciado sesion, 1= inicio sesion)
int login=0;

//-------------------------------------------------------------------------

//--------------------funciones de inicializacion------------------

int getsize(char *informacion){
	int i=0;
	while((informacion[i]!=0) && (informacion[i]!=127))
		i++;
	return i;
}

char* print(char *mostrar){
	return mostrar;
}

//establecer directorio del disco

void settime(){
	time_t t = time(0);
    struct tm *tlocal = localtime(&t);
    strftime(fecha,16,"%d/%m/%y %H:%M",tlocal);
}

void settime_reporte(){
	time_t t = time(0);
    struct tm *tlocal = localtime(&t);
    strftime(fecha,16,"%d_%m_%y-%H_%M",tlocal);
}

void set_disco(char nombre[50]){
	sprintf(directorio, "%s%s", sistema, nombre);
}

void set_disco_reporte(struct struct_disco tdisco, char reporte[50]){
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	fseek(f, mbr_address,SEEK_SET);
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		//leyendo para EXT3
		settime_reporte();
		sprintf(directorio_reporte, "%sEXT3%s_%s_%s.txt", sistema_reporte, tdisco.nombre, reporte, fecha);
	}else{
		//leyendo para FAT
		settime_reporte();
		sprintf(directorio_reporte, "%sFAT%s_%s_%s.txt", sistema_reporte, tdisco.nombre, reporte, fecha);
	}
	fclose(f);
}
//verifica si se tienen particiones

void inicializacion(){
	if( (d= opendir(sistema) )==NULL ){
		//no existe carpeta del sistema
		while(mkdir(sistema, 0777)==-1)
			printf("no");
		closedir(d);
	}
}

void inicializacion_reporte(){
	if( (d= opendir(sistema_reporte) )==NULL ){
		//no existe carpeta del sistema
		while(mkdir(sistema_reporte, 0777)==-1)
			printf("no");
		closedir(d);
	}
}

int probardenuevo(int salir){
	int out=0;
	while(out==0){
		printf("Probar de nuevo?\n");
		printf("1. Si\n");
		printf("2. No\n");
		int menu=0;
		if (scanf("%d", (&menu)) == 0){
			while (getchar() != '\n'){
				printf("%s","Error, ingrese numero: \n");
				scanf("%d", (&menu));
			}
		}
		if(menu==2){
			salir=1;
			out=1;
		}else if(menu==1){
			out=1;
		}else{
			printf("Error\n");
		}
	}
	return salir;
}

//inicio de sesion FAT
void FATlogin(struct struct_disco tdisco, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	fclose(f);
	//
	printf("\nInicio de sistema de archivos FAT...\n");
	if(strcmp(boot.b_usuario,"")!=0){
		int salir=0;
		while(salir==0){
			printf("Escriba nombre de usuario:\n");
			char usuario[50];
			scanf("%s", (usuario));
			printf("Password:\n");
			char password[50];
			scanf("%s", (password));
			if(strcmp(boot.b_usuario,usuario)!=0){
				printf("Usuario incorrecto\n");
				salir=probardenuevo(salir);
			}else if(strcmp(boot.b_password,password)!=0){
				printf("Password incorrecto\n");
				salir=probardenuevo(salir);
			}else{
				printf("Autentificado correctamente\n");
				login=1;
				salir=1;
			}
		}
	}else{
		login=1;
	}
	if(login==1)
		printf("Iniciando...\n");
	else
		printf("Cerrando Sistema de archivos FAT...\n");
}

char* cargarinformacion(char *d, char data[64]){
	char temporal1[getsize(d)];
	sprintf(temporal1,"%s",d);
	char temporal2[getsize(d)+getsize(data)];
	sprintf(temporal2,"%s%s",temporal1,data);
	d=temporal2;
	return d;
}

//obtener siguiente log libre

int Bitacora_nextfree(struct struct_disco tdisco, int activa){
	struct struct_log log;
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	//que tipo de sistema es?
	int tipo=0;//0==EXT3, 1=FAT
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		if(activa==0)
			tipo=1;
		else
			tipo=0;
	}else{
		if(activa==0)
			tipo=0;
		else
			tipo=1;
	}
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	int rtn=0;
	if(tipo==0){
		//leyendo para EXT3
		struct struct_superbloque superbloque;
		fread(&superbloque, sizeof(superbloque), 1, f);
		int read=atoi(superbloque.sb_ap_bitacora)+mbr_address;
		fseek(f, read,SEEK_SET);
		int max=atoi(superbloque.sb_numero_log);
		int t=0;
		for(t=0;(t<max) && (rtn==0);t++){
			fread(&log, sizeof(log), 1, f);
			if(atoi(log.log_activo)==0)
				rtn=t+1;
		}
	}else{
		//leyendo para FAT
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		rtn=atoi(boot.b_next_log_free);
	}
	fclose(f);
	return rtn;
}
//operaciones con inodos y tablas

struct struct_log Bitacora_obtener(int Llave, struct struct_disco tdisco, int activa){
	struct struct_log log;
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	//que tipo de sistema es?
	int tipo=0;//0==EXT3, 1=FAT
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		if(activa==0)
			tipo=1;
		else
			tipo=0;
	}else{
		if(activa==0)
			tipo=0;
		else
			tipo=1;
	}
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	int read=0;
	if(tipo==0){
		//leyendo para EXT3
		struct struct_superbloque superbloque;
		fread(&superbloque, sizeof(superbloque), 1, f);
		read=atoi(superbloque.sb_ap_bitacora)+mbr_address;
	}else{
		//leyendo para FAT
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		read=atoi(boot.b_ap_log)+mbr_address;
	}
	//leyendo estructuras
	fseek(f,read+(int)(sizeof(log)*(Llave-1)),SEEK_SET);
	fread(&log, sizeof(log), 1, f);
	fclose(f);
	return log;
}
	
struct struct_inodo EXT3obtener_inodo(int Llave, struct struct_disco tdisco, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//
	int read=atoi(superbloque.sb_first_inodo)+mbr_address;
	struct struct_inodo inodo;
	fseek(f,read+(int)(sizeof(inodo)*(Llave-1)),SEEK_SET);
	fread(&inodo, sizeof(inodo), 1, f);
	fclose(f);
	return inodo;
}

struct struct_inodo EXT3obtener_inodo_set_access(int Llave, struct struct_disco tdisco, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//
	int read=atoi(superbloque.sb_first_inodo)+mbr_address;
	struct struct_inodo inodo;
	fseek(f,read+(int)(sizeof(inodo)*(Llave-1)),SEEK_SET);
	fread(&inodo, sizeof(inodo), 1, f);
	//set acess
	settime();
	sprintf(inodo.i_time_last_access,"%s",fecha);
	fseek(f,read+(int)(sizeof(inodo)*(Llave-1)),SEEK_SET);
	fwrite(&inodo, sizeof(inodo), 1, f);
	fclose(f);
	return inodo;
}

struct struct_tabla FATobtener_tabla(int Llave, struct struct_disco tdisco, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	//
	int read=atoi(boot.b_ap_bloque_tabla_indexada)+address;
	struct struct_tabla tabla;
	fseek(f,read+(int)(sizeof(tabla)*(Llave-1)),SEEK_SET);
	fread(&tabla, sizeof(tabla), 1, f);
	fclose(f);
	return tabla;
}

void EXT3guardar_inodo(int Llave, struct struct_disco tdisco, struct struct_inodo inodo, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//
	int read=atoi(superbloque.sb_first_inodo)+mbr_address;
	fseek(f,read+(int)(sizeof(inodo)*(Llave-1)),SEEK_SET);
	fwrite(&inodo, sizeof(inodo), 1, f);
	fclose(f);
}

void FATguardar_tabla(int Llave, struct struct_disco tdisco, struct struct_tabla tabla, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	//
	int read=atoi(boot.b_ap_bloque_tabla_indexada)+address;
	fseek(f,read+(int)(sizeof(tabla)*(Llave-1)),SEEK_SET);
	fwrite(&tabla, sizeof(tabla), 1, f);
	fclose(f);
}

//operaciones con bloques y datos

void Bitacora_guardar(int Llave, struct struct_disco tdisco, struct struct_log log, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	//que tipo de sistema es?
	int tipo=0;//0==EXT3, 1=FAT
	//printf("TIPO:%s\n",mbr.mbr_tipo_sistema_archivos);
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		if(activa==0)
			tipo=1;
		else
			tipo=0;
	}else{
		if(activa==0)
			tipo=0;
		else
			tipo=1;
	}
	//printf("--TIPO:%d\n",tipo);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	int read=0;
	if(tipo==0){
		//leyendo para EXT3
		struct struct_superbloque superbloque;
		fread(&superbloque, sizeof(superbloque), 1, f);
		read=atoi(superbloque.sb_ap_bitacora)+mbr_address;
		fseek(f, mbr_address,SEEK_SET);
		//printf("LOG FREE SUPERBLOQUE:%d\n",atoi(superbloque.sb_log_free)-1);
		sprintf(superbloque.sb_log_free, "%d", atoi(superbloque.sb_log_free)-1);
		fwrite(&superbloque, sizeof(superbloque), 1, f);
	}else{
		//leyendo para FAT
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		read=atoi(boot.b_ap_log)+mbr_address;
		//next log free
		//int max=atoi(boot.b_log_free)+atoi(boot.b_log_count);
		//int t=Llave+1;
		sprintf(boot.b_next_log_free, "%d", Llave+1);
		/*for(t=0;t<max;t++){
			struct struct_log tlog;
			fread(&tlog, sizeof(tlog), 1, f);
			if((atoi(tlog.log_activo)==0) && (((t+1)>Llave))){
				sprintf(boot.b_next_log_free, "%d", t+1);
				t=max+1;
			}
				
		}*/
		fseek(f, mbr_address,SEEK_SET);
		//printf("LOG FREE BOOT:%d\n",atoi(boot.b_log_free)-1);
		//printf("LOG COUNT BOOT:%d\n",atoi(boot.b_log_count)+1);
		//printf("LOG NEXT FREE BOOT:%d\n",atoi(boot.b_next_log_free));
		sprintf(boot.b_log_free, "%d", atoi(boot.b_log_free)-1);
		sprintf(boot.b_log_count, "%d", atoi(boot.b_log_count)+1);
		fwrite(&boot, sizeof(boot), 1, f);
	}
	//leyendo estructuras
	fseek(f,read+(int)(sizeof(log)*(Llave-1)),SEEK_SET);
	fwrite(&log, sizeof(log), 1, f);
	fclose(f);
}

struct struct_bloque EXT3obtener_bloque(int Llave, struct struct_disco tdisco, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	if(atoi(superbloque.sb_numero_bloques)<Llave)
		Llave=1;
	//
	int read=atoi(superbloque.sb_first_bloque)+mbr_address;
	struct struct_bloque bloque;
	fseek(f,read+(Llave-1)*sizeof(bloque),SEEK_SET);
	fread(&bloque, sizeof(bloque), 1, f);
	fclose(f);
	return bloque;
}

struct struct_datos FATobtener_datos(int Llave, struct struct_disco tdisco, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	//
	int read=atoi(boot.b_ap_bloque_datos)+address;
	struct struct_datos datos;
	fseek(f,read+(Llave-1)*sizeof(datos),SEEK_SET);
	fread(&datos, sizeof(datos), 1, f);
	fclose(f);
	return datos;
}

void EXT3guardar_bloque(int Llave, struct struct_disco tdisco, struct struct_bloque bloque, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		 mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//
	int read=atoi(superbloque.sb_first_bloque)+mbr_address;
	fseek(f,read+(Llave-1)*sizeof(bloque),SEEK_SET);
	fwrite(&bloque, sizeof(bloque), 1, f);
	fclose(f);
}

void FATguardar_datos(int Llave, struct struct_disco tdisco, struct struct_datos datos, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	//
	int read=atoi(boot.b_ap_bloque_datos)+address;
	fseek(f,read+(Llave-1)*sizeof(datos),SEEK_SET);
	fwrite(&datos, sizeof(datos), 1, f);
	fclose(f);
}

//----------------------------------------------------------------

//bitacora

void Bitacora_registro(char tipo_operacion[50], int file0_folder1, char direccion[640], char *informacion, struct struct_disco tdisco, int activa){
	settime();
	struct struct_log log;
	sprintf(log.log_fecha, "%s", fecha);//Fecha de transacción
	sprintf(log.log_activo, "%d", 1);//si esta activo
	if(getsize(tipo_operacion)>51){
		int t=0;
		for(t=50;t>2;t--)
			log.log_tipo_operacion[t]=tipo_operacion[t];
		log.log_tipo_operacion[2]='.';
		log.log_tipo_operacion[1]='.';
		log.log_tipo_operacion[0]='.';
	}else
		sprintf(log.log_tipo_operacion, "%s", tipo_operacion);//El tipo de operación a realizarse
	sprintf(log.log_tipo, "%d", file0_folder1);//Si es archivo (0), sies directorio(1)
	sprintf(log.log_nombre, "%s", direccion);//Nombre archivo o directorio(path completo)
	char copy[getsize(informacion)];
	sprintf(copy, "%s", informacion);
	if(getsize(copy)>508){
		int t=0;
		for(t=0;t<507;t++)
			log.log_contenido[t]=copy[t];
		log.log_contenido[507]='.';
		log.log_contenido[508]='.';
		log.log_contenido[509]='.';
	}else
		sprintf(log.log_contenido, "%s", copy);//Si hay datos contenidos(512)
	int next_free=Bitacora_nextfree(tdisco, activa);
	//printf("Next activa: %d\n", next_free);
	Bitacora_guardar(next_free, tdisco, log, activa);
}

void Bitacora_reporte(struct struct_disco tdisco){
	set_disco_reporte(tdisco,"bitacora");
	printf("Reporte creado en:\n-------------\n");
	printf("%s\n-------------\n", directorio_reporte);
	printf("Presione una tecla para continuar...\n");
	FILE *freporte=freopen(directorio_reporte, "w" ,stdout);
	printf("Reporte de bitacora:\n\n");
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	fseek(f, mbr_address,SEEK_SET);
	int read=0;
	int max=0;
	int min=0;
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		//leyendo para EXT3
		struct struct_superbloque superbloque;
		fread(&superbloque, sizeof(superbloque), 1, f);
		read=atoi(superbloque.sb_ap_bitacora)+mbr_address;
		max=atoi(superbloque.sb_numero_log);
		min=max-atoi(superbloque.sb_log_free);
	}else{
		//leyendo para FAT
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		read=atoi(boot.b_ap_log)+mbr_address;
		max=atoi(boot.b_log_count)+atoi(boot.b_log_free);
		min=atoi(boot.b_log_count);
	}
	//leyendo estructuras
	fseek(f,read,SEEK_SET);
	int t=0;
	struct struct_log log;
	int contador=0;
	//printf("MAX:%d -- MIN:%d\n",max, min);
	for(t=0;t<max;t++){
		fread(&log, sizeof(log), 1, f);
		if(atoi(log.log_activo)==1){
			/*reporte*/
			printf("\n--\nLog: %d\n",(t+1));
			printf("El tipo de operación a realizada: %s\n", log.log_tipo_operacion);
			if(atoi(log.log_tipo)==0)
				printf("Operacion realizada sobre archivo\n");
			else
				printf("Operacion realizada sobre carpeta\n");
			printf("Path: %s\n", log.log_nombre);
			printf("Contenido: %s\n", log.log_contenido);
			printf("Fecha de transaccion: %s\n", log.log_fecha);
			contador++;
			//printf("contador%d>=min:%d\n",contador, min);
			if(contador>=min)
				t=max+1;
		}
	}
	printf("\n");
	fclose(freporte);
	freopen("/dev/tty","w",stdout); 
	fclose(f);
	//salida
	char c;
	scanf("%c",&c);
	getchar();
}

//navegador EXT3

char* EXT3loaddata(char *informacion, struct struct_disco tdisco, struct struct_inodo inodo, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//----
	//printf("inodo.bloque1:%s\n",inodo.i_block1);
	//printf("inodo.bloque2:%s\n",inodo.i_block2);
	//printf("inodo.bloque3:%s\n",inodo.i_block3);
	//printf("inodo.bloque4:%s\n",inodo.i_block4);
	//printf("inodo.bloque5:%s\n",inodo.i_Iblock);
	//----
	struct struct_bloque bloque=EXT3obtener_bloque(atoi(inodo.i_block1),tdisco, activa);
	//lee el primer bloque
	char *rtn;
	informacion=cargarinformacion(informacion, bloque.data);
	char temporal0[getsize(informacion)];
	sprintf(temporal0,"%s", informacion);
	//printf("info:%s\n",temporal0);
	if(atoi(inodo.i_block2)!=0){
		temporal0[getsize(temporal0)]=0;
		//printf("inodo.informacion211:%s\n",bloque.data);
		//sprintf(bloque.data,"%s","");
		struct struct_bloque bloque2=EXT3obtener_bloque(atoi(inodo.i_block2),tdisco, activa);
		//lee el segundo bloque
		//printf("info:%s\n",informacion);
		char temporal1[getsize(temporal0)];
		char temporal2[getsize(bloque2.data)];
		char temporal3[getsize(temporal0)+getsize(bloque2.data)];
		sprintf(temporal1,"%s",temporal0);
		sprintf(temporal2,"%s",bloque2.data);
		sprintf(temporal3,"%s%s",temporal1,temporal2);
		//printf("t3:%s\n",temporal3);
		//char *informacion2=cargarinformacion(informacion, bloque2.data);
		//printf("inodo.informacion22:%s\n",bloque2.data);
		if(atoi(inodo.i_block3)!=0){
			temporal3[getsize(temporal3)-1]=0;
			//printf("inodo.informacion22:%s\n",temporal3);
			//sprintf(bloque.data,"%s","");
			struct struct_bloque bloque3=EXT3obtener_bloque(atoi(inodo.i_block3),tdisco, activa);
			//lee el tercero bloque
			char temporal4[getsize(temporal3)-1];
			char temporal5[getsize(bloque3.data)];
			char temporal6[getsize(temporal3)+getsize(bloque3.data)-1];
			sprintf(temporal4,"%s",temporal3);
			sprintf(temporal5,"%s",bloque3.data);
			sprintf(temporal6,"%s%s",temporal4,temporal5);
			//printf("t6:%s\n",temporal6);
			//char *informacion3=cargarinformacion(informacion2, bloque.data);
			//printf("inodo.informacion33:%s\n",bloque.data);
			if(atoi(inodo.i_block4)!=0){
				temporal6[getsize(temporal6)]=0;
				sprintf(bloque.data,"%s","");
				struct struct_bloque bloque4=EXT3obtener_bloque(atoi(inodo.i_block4),tdisco, activa);
				//lee el cuarto bloque
				char temporal7[getsize(temporal6)];
				char temporal8[getsize(bloque4.data)];
				char temporal9[getsize(temporal6)+getsize(bloque4.data)];
				sprintf(temporal7,"%s",temporal6);
				sprintf(temporal8,"%s",bloque4.data);
				sprintf(temporal9,"%s%s",temporal7,temporal8);
				//printf("t9:%s\n",temporal9);
				//char *informacion4=cargarinformacion(informacion3, bloque.data);
				//printf("inodo.informacion44:%s\n",bloque.data);
				if(atoi(inodo.i_Iblock)!=0){
					temporal9[getsize(temporal9)]=0;
					struct struct_inodo tinodo=EXT3obtener_inodo(atoi(inodo.i_Iblock),tdisco, activa);
					//lee el inodo enlazado
					char *empty=temporal9;
					char *informacion5=EXT3loaddata(empty, tdisco, tinodo, activa);
					//printf("inodo.informacion5:%s\n",informacion5);
					rtn=informacion5;
				}else
					rtn=temporal9;
			}else
				rtn=temporal6;
		}else
			rtn=temporal3;
	}else
		rtn=temporal0;
	//error de c
	char tinformacion[getsize(rtn)];
	for(ifor=0;ifor<getsize(rtn);ifor++)
		tinformacion[ifor]=0;
	sprintf(tinformacion,"%s",rtn);
	fclose(f);
	char *rtn2=tinformacion;
	return rtn2;
}

void EXT3_bloque_mostrar_informacion(struct struct_bloque bloque, int id){
	printf("\n");
	printf("'\\n' representado por '/#'\n");
	printf("bloque.id=%d\n",id);
	printf("bloque.estado=%s\n",bloque.estado);
	if(atoi(bloque.estado)!=0){
		int add=0;
		int t=0;
		for(t=0;t<getsize(bloque.data);t++){
			if(bloque.data[t]==10)
				add=add+2;
		}
		char output[getsize(bloque.data)+1+add];
		int count=0;
		for(t=0;t<getsize(bloque.data)+add;t++){
			if(bloque.data[t]==10){
				output[count]=47;
				count++;
				output[count]='#';
				count++;
			}else{
				output[count]=bloque.data[t];
				count++;
			}
		}
		output[t]=0;
		printf("bloque.data='%s'\n",output);
		printf("\n");
	}else
		printf("bloque.data=''\n");
}

void EXT3_inodo_mostrar_informacion(struct struct_inodo inodo){
	printf("\n");
	printf("nodo.id=%s\n",inodo.Llave);//Indicara el id del inodo
	printf("nodo.i_tipo=%s\n",inodo.i_tipo);//tipo: file o dir
	printf("nodo.i_date_mod=%s\n",inodo.i_date_mod);//Fecha y hora del último cambio al contenido de esta estructura
	printf("inodo.i_tam_archivo=%s\n",inodo.i_tam_archivo);//Indicar el tamaño del archivo(en bytes)
	printf("inodo.i_asig_bloques=%s\n",inodo.i_asig_bloques);//Numero de bloques asignados
	printf("inodo.i_time_last_access=%s\n",inodo.i_time_last_access);//Tiempo de último acceso. Es decir la fecha en la cual se accedió a este inodo para obtener información de sus carpetas o archivos hijos.
	printf("inodo.i_ctime=%s\n",inodo.i_ctime);//Fecha y hora de creación del inodo
	printf("inodo.i_block1=%s\n",inodo.i_block1);//Bloque directo 1
	printf("inodo.i_block2=%s\n",inodo.i_block2);//Bloque directo 2
	printf("inodo.i_block3=%s\n",inodo.i_block3);//Bloque directo 3
	printf("inodo.i_block4=%s\n",inodo.i_block4);//Bloque directo 4
	printf("inodo.i_Iblock=%s\n",inodo.i_Iblock);//Bloque indirecto
	printf("\n");
}

char* EXT3loaddata_ruta_bloques(char *informacion, struct struct_disco tdisco, struct struct_inodo inodo, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//----
	//printf("inodo.bloque1:%s\n",inodo.i_block1);
	//printf("inodo.bloque2:%s\n",inodo.i_block2);
	//printf("inodo.bloque3:%s\n",inodo.i_block3);
	//printf("inodo.bloque4:%s\n",inodo.i_block4);
	//printf("inodo.bloque5:%s\n",inodo.i_Iblock);
	//----
	struct struct_bloque bloque=EXT3obtener_bloque(atoi(inodo.i_block1),tdisco, activa);
	EXT3_bloque_mostrar_informacion(bloque, atoi(inodo.i_block1));
	//lee el primer bloque
	char *rtn;
	informacion=cargarinformacion(informacion, bloque.data);
	char temporal0[getsize(informacion)];
	sprintf(temporal0,"%s", informacion);
	//printf("info:%s\n",temporal0);
	if(atoi(inodo.i_block2)!=0){
		temporal0[getsize(temporal0)]=0;
		//printf("inodo.informacion211:%s\n",bloque.data);
		//sprintf(bloque.data,"%s","");
		struct struct_bloque bloque2=EXT3obtener_bloque(atoi(inodo.i_block2),tdisco, activa);
		EXT3_bloque_mostrar_informacion(bloque2, atoi(inodo.i_block2));
		//lee el segundo bloque
		//printf("info:%s\n",informacion);
		char temporal1[getsize(temporal0)];
		char temporal2[getsize(bloque2.data)];
		char temporal3[getsize(temporal0)+getsize(bloque2.data)];
		sprintf(temporal1,"%s",temporal0);
		sprintf(temporal2,"%s",bloque2.data);
		sprintf(temporal3,"%s%s",temporal1,temporal2);
		//printf("t3:%s\n",temporal3);
		//char *informacion2=cargarinformacion(informacion, bloque2.data);
		//printf("inodo.informacion22:%s\n",bloque2.data);
		if(atoi(inodo.i_block3)!=0){
			temporal3[getsize(temporal3)-1]=0;
			//printf("inodo.informacion22:%s\n",temporal3);
			//sprintf(bloque.data,"%s","");
			struct struct_bloque bloque3=EXT3obtener_bloque(atoi(inodo.i_block3),tdisco, activa);
			EXT3_bloque_mostrar_informacion(bloque3, atoi(inodo.i_block3));
			//lee el tercero bloque
			char temporal4[getsize(temporal3)-1];
			char temporal5[getsize(bloque3.data)];
			char temporal6[getsize(temporal3)+getsize(bloque3.data)-1];
			sprintf(temporal4,"%s",temporal3);
			sprintf(temporal5,"%s",bloque3.data);
			sprintf(temporal6,"%s%s",temporal4,temporal5);
			//printf("t6:%s\n",temporal6);
			//char *informacion3=cargarinformacion(informacion2, bloque.data);
			//printf("inodo.informacion33:%s\n",bloque.data);
			if(atoi(inodo.i_block4)!=0){
				temporal6[getsize(temporal6)]=0;
				sprintf(bloque.data,"%s","");
				struct struct_bloque bloque4=EXT3obtener_bloque(atoi(inodo.i_block4),tdisco, activa);
				EXT3_bloque_mostrar_informacion(bloque4, atoi(inodo.i_block4));
				//lee el cuarto bloque
				char temporal7[getsize(temporal6)];
				char temporal8[getsize(bloque4.data)];
				char temporal9[getsize(temporal6)+getsize(bloque4.data)];
				sprintf(temporal7,"%s",temporal6);
				sprintf(temporal8,"%s",bloque4.data);
				sprintf(temporal9,"%s%s",temporal7,temporal8);
				//printf("t9:%s\n",temporal9);
				//char *informacion4=cargarinformacion(informacion3, bloque.data);
				//printf("inodo.informacion44:%s\n",bloque.data);
				if(atoi(inodo.i_Iblock)!=0){
					temporal9[getsize(temporal9)]=0;
					struct struct_inodo tinodo=EXT3obtener_inodo(atoi(inodo.i_Iblock),tdisco, activa);
					EXT3_inodo_mostrar_informacion(tinodo);
					//lee el inodo enlazado
					char *empty=temporal9;
					char *informacion5=EXT3loaddata_ruta_bloques(empty, tdisco, tinodo, activa);
					//printf("inodo.informacion5:%s\n",informacion5);
					rtn=informacion5;
				}else
					rtn=temporal9;
			}else
				rtn=temporal6;
		}else
			rtn=temporal3;
	}else
		rtn=temporal0;
	//error de c
	char tinformacion[getsize(rtn)];
	for(ifor=0;ifor<getsize(rtn);ifor++)
		tinformacion[ifor]=0;
	sprintf(tinformacion,"%s",rtn);
	fclose(f);
	char *rtn2=tinformacion;
	return rtn2;
}

char* FATloaddata(int apuntador, struct struct_disco tdisco, int activa){
	char *rtn;
	struct struct_datos datos=FATobtener_datos(apuntador, tdisco, activa);
	char *informacion=datos.bd_data;
	char temporal0[getsize(informacion)];
	sprintf(temporal0,"%s", informacion);
	//printf("dato1->:%d->:%s\n",apuntador, temporal0);
	if(atoi(datos.bd_ap_directo_siguiente)!=0){
		temporal0[getsize(informacion)-1]=0;
		char *siguiente=FATloaddata(atoi(datos.bd_ap_directo_siguiente), tdisco, activa);
		char temporal1[getsize(siguiente)];
		sprintf(temporal1, "%s", siguiente);
		char temporal2[getsize(temporal1)+getsize(temporal0)];
		sprintf(temporal2, "%s%s", temporal0, temporal1);
		//printf("!concatenado:%s\n", temporal2);
		rtn=temporal2;
	}else{
		rtn=temporal0;
	}
	//error de c
	return rtn;
}

//devuelve el inodo de la seleccion menu del inodo inodo, y el nombre de la seleccion
struct struct_inodo_ubicacion EXT3get_inodo_from_seleccion(int menu, struct struct_inodo inodo, struct struct_disco tdisco, int activa){
	char *informacion="";
	informacion=EXT3loaddata(informacion, tdisco, inodo, activa);
	//buscando el id seleccionado
	int k=0;
	int activar=0;
	char id[7];
	char ubicacion[640];
	int opcion=1;
	int iniword=0;
	for(k=0;(k<getsize(informacion)) & (informacion[k]!=0);k++){
		if(informacion[k]==10){
			activar=0;
			opcion++;
			iniword=0;
		}
		if((activar==1) & (menu==opcion)){
			if(informacion[k-1]==32)
				sprintf(id, "%c", informacion[k]);
			else
				sprintf(id, "%s%c", id, informacion[k]);
		}
		if(informacion[k]==32){
			activar=1;
		}
		if((informacion[k]!=10) & (activar==0) & (menu==opcion)){
			if(iniword==0){
				sprintf(ubicacion, "%c", informacion[k]);
				iniword=1;
			}else
				sprintf(ubicacion, "%s%c", ubicacion, informacion[k]);
		}
	}
	//se tiene el numero de inodo:id, y el nombre de archivo o folder:ubicacion
	//obteniendo nuevo inodo
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f,mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	struct struct_inodo seleccion=EXT3obtener_inodo(atoi(id), tdisco, activa);
	//regresando informacion
	struct struct_inodo_ubicacion inodo_ubicacion;
	inodo_ubicacion.inodo=seleccion;
	sprintf(inodo_ubicacion.ubicacion, "%s", ubicacion);
	fclose(f);
	return inodo_ubicacion;
}

//devuelve la tabla de la seleccion menu, y el nombre de la seleccion
struct struct_tabla FATget_tabla_from_seleccion(int menu, int nivel, char padre[50], struct struct_disco tdisco, int activo){
	struct struct_tabla tabla;
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int address=atoi(mbr.mbr_byte_particion);
	if(activo==0)
		address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, address, SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	int tfree=atoi(boot.b_tablas_free);
	int tcount=atoi(boot.b_tablas_count);
	int ttotal=tfree+tcount;
	int k=0;
	int leidos=0;
	int contador=1;
	//printf("buscando:%d:%d:%s:\n",menu,nivel,padre);
	//for(k=0;k<10; k++){
	//	fread(&tabla, sizeof(tabla), 1, f);
	//	printf("leyendo:%s:%s:%s:\n",tabla.lista_nombre,tabla.lista_nivel,tabla.lista_nombre_padre);
	//}
	//fseek(f, address+sizeof(boot), SEEK_SET);
	//printf("buscando:%d:%d:%s:\n",menu,nivel,padre);
	for(k=0;(k<ttotal) && (leidos<tcount); k++){
		//printf("(k:%d<ttotal:%d) && (leidos:%d<tcount:%d)\n",k, ttotal, leidos, tcount);
		fread(&tabla, sizeof(tabla), 1, f);
		//printf("->leyendo:%s:%s:%s:\n",tabla.lista_nombre,tabla.lista_nivel,tabla.lista_nombre_padre);
		//printf("tabla.disponible:%s==1\n",tabla.disponible);
		if(atoi(tabla.disponible)==1){
			leidos++;
			//printf("(atoi(tabla.lista_nivel:%s)==nivel:%d) && (strcmp(tabla.lista_nombre_padre:%s,padre:%s)==0)\n",tabla.lista_nivel, nivel, tabla.lista_nombre_padre, padre);
			if((atoi(tabla.lista_nivel)==nivel) && (strcmp(tabla.lista_nombre_padre,padre)==0)){
				//printf("contador:%d==menu:%d\n",contador, menu);
				if(contador==menu)
					leidos=tcount+1;
				contador++;
			}
		}
	}
	fclose(f);
	return tabla;
}

//recive un id de inodo, si es folder elimina cada archivo dentro de este, de ultimo se elimina a si mismo
void EXT3_delete_all(char direccion[640], int illave, struct struct_disco tdisco, int activa, int mostrar){
	struct struct_inodo inodo=EXT3obtener_inodo(illave, tdisco, activa);
	//printf("tipo: %s\n", inodo.i_tipo);
	if(strcmp(inodo.i_tipo,"dir")==0){
		char *informacion="";
		informacion=EXT3loaddata(informacion, tdisco, inodo, activa);
		//buscando el id seleccionado
		int k=0;
		int activar=0;
		char id[7];
		char ubicacion[640];
		int opcion=1;
		int iniword=0;
		int contador=1;
		for(k=0;(k<getsize(informacion)) & (informacion[k]!=0);k++){
			if(informacion[k]==10){
				activar=0;
				opcion++;
				iniword=0;
				if(contador>2){
					char nueva_ubicacion[640];
					struct struct_inodo itemp=EXT3obtener_inodo(atoi(id), tdisco, activa);
					if(strcmp(itemp.i_tipo,"dir")==0){
						sprintf(nueva_ubicacion, "%s%s/", direccion, ubicacion);
					}else{
						sprintf(nueva_ubicacion, "%s%s", direccion, ubicacion);
					}
					//printf("ingresando:%s - id:%s\n", ubicacion, id);
					EXT3_delete_all(nueva_ubicacion, atoi(id), tdisco, activa, mostrar);
				}
				contador++;
			}
			if(activar==1){
				if(informacion[k-1]==32)
					sprintf(id, "%c", informacion[k]);
				else
					sprintf(id, "%s%c", id, informacion[k]);
			}
			if(informacion[k]==32){
				activar=1;
			}
			if((informacion[k]!=10) & (activar==0)){
				if(iniword==0){
					sprintf(ubicacion, "%c", informacion[k]);
					iniword=1;
				}else
					sprintf(ubicacion, "%s%c", ubicacion, informacion[k]);
			}
		}
	}
	struct struct_bloque bloque;
	//eliminando bloque 1
	sprintf(bloque.estado, "%d", 0);
	int pb1=atoi(inodo.i_block1);
	EXT3guardar_bloque(pb1, tdisco, bloque, activa);
	int pb2=atoi(inodo.i_block2);
	int pb3=0;
	int pb4=0;
	int pi=0;
	if(pb2!=0){
		EXT3guardar_bloque(atoi(inodo.i_block2), tdisco, bloque, activa);
		pb3=atoi(inodo.i_block3);
		if(pb3!=0){
			EXT3guardar_bloque(atoi(inodo.i_block3), tdisco, bloque, activa);
			pb4=atoi(inodo.i_block4);
			if(pb4!=0){
				EXT3guardar_bloque(atoi(inodo.i_block4), tdisco, bloque, activa);
				pi=atoi(inodo.i_Iblock);
				if(pi!=0){
					struct struct_inodo tinodo;
					settime();
					sprintf(tinodo.i_date_mod,"%s", fecha);
					sprintf(tinodo.i_ctime, "%s", fecha);
					sprintf(tinodo.i_time_last_access, "%s", "00/00/0000 00:00");
					sprintf(tinodo.i_tam_archivo,"%d", 0);
					sprintf(tinodo.i_asig_bloques,"%d", 0);
					sprintf(tinodo.i_block1,"%d", 0);
					sprintf(tinodo.i_block2,"%d", 0);
					sprintf(tinodo.i_block3,"%d", 0);
					sprintf(tinodo.i_block4,"%d", 0);
					sprintf(tinodo.i_Iblock,"%d", 0);
					sprintf(tinodo.Llave,"%d", atoi(inodo.i_Iblock));
					EXT3guardar_inodo(atoi(inodo.i_Iblock), tdisco, tinodo, activa);
				}
			}
		}
	}
	//actualizando superbloque
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//obteniendo el mapa PI
	char mpi[atoi(superbloque.sb_numero_inodos)];
	fread(&mpi,sizeof(mpi),1,f);
	//obteniendo el mapa PB
	char mpb[atoi(superbloque.sb_numero_bloques)];
	fread(&mpb,sizeof(mpb),1,f);
	int busados=0;
	if(pb1!=0){
		busados++;
		mpb[pb1-1]=0;
	}
	if(pb2!=0){
		busados++;
		mpb[pb2-1]=0;
	}
	if(pb3!=0){
		busados++;
		mpb[pb3-1]=0;
	}
	if(pb4!=0){
		busados++;
		mpb[pb4-1]=0;
	}
	int iusados=1;
	if(pi!=0){
		iusados++;
		mpi[pi-1]=0;
	}
	int ilibre=0;
	int t=0;
	for(t=0;(t<atoi(superbloque.sb_numero_bloques)) && (ilibre==0);t++){
		if(mpi[t]==0)
			ilibre=t+1;
	}
	int blibre=0;
	t=0;
	for(t=0;(t<atoi(superbloque.sb_numero_bloques)) && (blibre==0);t++){
		if(mpb[t]==0)
			blibre=t+1;
	}
	sprintf(superbloque.sb_bloques_freee, "%d", atoi(superbloque.sb_bloques_freee)+busados);//Cantidad de bloques de datos libres.
	sprintf(superbloque.sb_inodos_free, "%d", atoi(superbloque.sb_inodos_free)+busados);//Cantidad de i-nodos libres.
	sprintf(superbloque.sb_fist_free_bitmapinodo, "%d", ilibre);//Primer bit libre en el bitmap de i-nodo
	sprintf(superbloque.sb_first_free_bitmapbloque, "%d", blibre);// Primer bit libre en el bitmap de bloque de datos.
	//escribiendo
	fseek(f, mbr_address,SEEK_SET);
	fwrite(&superbloque, sizeof(superbloque), 1, f);
	//obteniendo el mapa PI
	fwrite(&mpi,sizeof(mpi),1,f);
	//obteniendo el mapa PB
	fwrite(&mpb,sizeof(mpb),1,f);
	fclose(f);
	if(activa!=0 && mostrar==1)
		printf("%s .. eliminado\n", direccion);
}

void FAT_delete_all_data(int llave, struct struct_disco tdisco, int activa){
	//si contiene mas bloques ligados, los elimina
	struct struct_datos eliminando_datos=FATobtener_datos(llave, tdisco, activa);
	if(atoi(eliminando_datos.bd_ap_directo_siguiente)!=0)
		FAT_delete_all_data(atoi(eliminando_datos.bd_ap_directo_siguiente), tdisco, activa);
	//eliminado bloque de datos
	struct struct_datos datos;
	sprintf(datos.disponible, "%d", 0);
	sprintf(datos.bd_ap_directo_siguiente, "%d", 0);
	FATguardar_datos(llave, tdisco, datos, activa);
	//actualizando boot
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr y superbloque
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	//editando boot
	sprintf(boot.b_bloques_count,"%d", atoi(boot.b_bloques_count)-1);//Cantidad de bloque de datos
	sprintf(boot.b_bloques_free,"%d", atoi(boot.b_bloques_free)+1);//Cantidad de bloques de datos libres
	//buscando siguiente bloque libre
	int posicion=atoi(boot.b_ap_bloque_datos)+mbr_address;
	fseek(f, posicion, SEEK_SET);
	int ttotal=atoi(boot.b_bloques_free)+atoi(boot.b_bloques_count);
	int k=0;
	int libre=0;
	for(k=0;(k<ttotal) && (libre==0); k++){
		struct struct_datos tdatos;
		fread(&tdatos, sizeof(tdatos), 1, f);
		if(atoi(tdatos.disponible)==0)
			libre=k+1;
	}
	sprintf(boot.b_next_bloque_free,"%d", libre);//siguiente bloque libre
	//actualizando
	fseek(f, mbr_address,SEEK_SET);
	fwrite(&boot, sizeof(boot), 1, f);
	fclose(f);
}

void FAT_delete_all_tabla(char direccion[640], int nivel, int apuntador, char padre[50], struct struct_disco tdisco, int activa, int mostrar){	
	//estructuras
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	struct struct_boot boot;
	fseek(f,mbr_address,SEEK_SET);
	fread(&boot, sizeof(boot), 1, f);
	fclose(f);
	int ttotal=0;
	int k=0;
	//obteniendo tabla
	struct struct_tabla tabla=FATobtener_tabla(apuntador, tdisco, activa);
	//si contiene datos, los elimina
	if(atoi(tabla.lista_ap_directo_bloque)!=-1){
		FAT_delete_all_data(atoi(tabla.lista_ap_directo_bloque), tdisco, activa);
	}else{
		//buscando carpetas o archivos contenidos
		set_disco(tdisco.nombre);
		f = fopen (directorio, "rb+");
		fseek(f,mbr_address+atoi(boot.b_ap_bloque_tabla_indexada),SEEK_SET);
		int tfree=atoi(boot.b_tablas_free);
		int tcount=atoi(boot.b_tablas_count);
		ttotal=tfree+tcount;
		k=0;
		int leidos=0;
		//printf("----->buscando:%d:%s:\n",nivel,padre);
		//printf("----->leidos:%d:---->ttotal:%d::---->tcount:%d:\n",leidos, ttotal, tcount);
		for(k=0;(k<ttotal) && (leidos<tcount); k++){
		//for(k=0;(k<10); k++){
			struct struct_tabla dtabla;
			fread(&dtabla, sizeof(dtabla), 1, f);
			//printf("----->leyendo:%s:%s:%s:\n",dtabla.lista_nombre,dtabla.lista_nivel,dtabla.lista_nombre_padre);
			//printf("----->IF:::==1:tabla %d disponible:%d\n",k, atoi(dtabla.disponible));
			//printf("----->tabla nivel:%d\n", atoi(dtabla.lista_nivel));
			if(atoi(dtabla.disponible)==1){
				leidos++;
				//printf("----->(atoi(dtabla.lista_nivel):%s==nivel:%d) && (strcmp(dtabla.lista_nombre_padre:%s,padre:%s)==0)\n",dtabla.lista_nivel, nivel, dtabla.lista_nombre_padre, padre);
				if((atoi(dtabla.lista_nivel)==nivel) && (strcmp(dtabla.lista_nombre_padre,padre)==0)){
					char direccion_nueva[640];
					sprintf(direccion_nueva, "%s%s/", direccion, dtabla.lista_nombre);
					if(atoi(dtabla.lista_ap_directo_bloque)!=-1)
						sprintf(direccion_nueva, "%s%s", direccion, dtabla.lista_nombre);
					FAT_delete_all_tabla(direccion_nueva, nivel+1, k+1, dtabla.lista_nombre, tdisco, activa, mostrar);
				}
			}
		}
		fclose(f);
	}
	//eliminando tabla
	struct struct_tabla nueva;
	//escribiendo tabla vacia
	sprintf(nueva.disponible, "%d", 0);
	sprintf(nueva.lista_ap_directo_bloque, "%d", -1);
	sprintf(nueva.lista_nombre_padre, "%s", "");
	FATguardar_tabla(apuntador, tdisco, nueva, activa);
	//actualizando datos en el boot
	set_disco(tdisco.nombre);
	f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr y superbloque
	fread(&mbr, sizeof(mbr), 1, f);
	fseek(f, mbr_address,SEEK_SET);
	fread(&boot, sizeof(boot), 1, f);
	//editando boot
	sprintf(boot.b_tablas_count,"%d", atoi(boot.b_tablas_count)-1);//Cantidad de bloque de datos
	sprintf(boot.b_tablas_free,"%d", atoi(boot.b_tablas_free)+1);//Cantidad de bloques de datos libres
	//buscando siguiente bloque libre
	int posicion=atoi(boot.b_ap_bloque_tabla_indexada)+mbr_address;
	fseek(f, posicion, SEEK_SET);
	ttotal=atoi(boot.b_tablas_free)+atoi(boot.b_tablas_count);
	k=0;
	int libre=0;
	for(k=0;(k<ttotal) && (libre==0); k++){
		struct struct_tabla ttabla;
		fread(&ttabla, sizeof(ttabla), 1, f);
		if(atoi(ttabla.disponible)==0)
			libre=k+1;
	}
	sprintf(boot.b_next_tabla_free,"%d", libre);//siguiente bloque libre
	//actualizando
	fseek(f, mbr_address,SEEK_SET);
	fwrite(&boot, sizeof(boot), 1, f);
	fclose(f);
	if((activa!=0) && (mostrar==1))
		printf("%s .. eliminado\n", direccion);
}

//guarda la informacion
int EXT3guardar(struct struct_disco tdisco, char *informacion, char tipo[4], int activa){
	int pi_usado=0;
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	struct struct_mbr mbr;
	fseek(f,(int)(sizeof(tdisco)),SEEK_SET);
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//obteniendo el PI
	int pi=atoi(superbloque.sb_fist_free_bitmapinodo);
	pi_usado=pi;
	//obteniendo el PB
	int pb=atoi(superbloque.sb_first_free_bitmapbloque);
	//obteniendo el mapa PI
	char mpi[atoi(superbloque.sb_numero_inodos)];
	fread(&mpi,sizeof(mpi),1,f);
	//obteniendo el mapa PB
	char mpb[atoi(superbloque.sb_numero_bloques)];
	fread(&mpb,sizeof(mpb),1,f);
	//obteniendo el Inodo
	struct struct_inodo new_inodo=EXT3obtener_inodo(pi, tdisco, activa);
	//configurando inodo
	int size=getsize(informacion);
	char *i1="";
	char b4[64];
	for(ifor=0;ifor<64;ifor++)b4[ifor]=0;
	char b3[64];
	for(ifor=0;ifor<64;ifor++)b3[ifor]=0;
	char b2[64];
	for(ifor=0;ifor<64;ifor++)b2[ifor]=0;
	char b1[64];
	for(ifor=0;ifor<64;ifor++)b1[ifor]=0;
	int bandera=0;
	//printf("Guardando1:%s:\n",b1);
	//printf("Guardando2:%s:\n",b2);
	//printf("Guardando3:%s:\n",b3);
	//printf("Guardando4:%s:\n",b4);
	for(ifor=0;ifor<size;ifor++){
		if(ifor<64){
			b1[ifor]=informacion[ifor];
			//printf("-->1:%s:\n",b1);
			bandera=1;
		}else if(ifor<128){
			b2[ifor-64]=informacion[ifor];
			//printf("-->12:%s:\n",b1);
			bandera=2;
		}else if(ifor<192){
			b3[ifor-128]=informacion[ifor];
			//printf("-->13:%s:\n",b1);
			bandera=3;
		}else if(ifor<256){
			b4[ifor-192]=informacion[ifor];
			//printf("-->14:%s:\n",b1);
			bandera=4;
		}else{
			int s=getsize(i1);
			char temporal3[s+1];
			sprintf(temporal3,"%s%c", i1, informacion[ifor]);
			i1=temporal3;
			bandera=5;
		}
	}
	switch(bandera){
		case 2: 
			b1[getsize(b1)-3]=0;
		break;
		case 3: 
			b1[getsize(b1)-3]=0;
			b2[getsize(b2)]=0;
		break;
		case 4: 
			b1[getsize(b1)-3]=0;
			b2[getsize(b2)]=0;
			b3[getsize(b3)]=0;
		break;
		case 5: 
			b1[getsize(b1)-3]=0;
			b2[getsize(b2)]=0;
			b3[getsize(b3)]=0;
			b4[getsize(b4)]=0;
		break;
	}
	//printf("Guardando1:%s:\n",b1);
	//printf("Guardando2:%s:\n",b2);
	//printf("Guardando3:%s:\n",b3);
	//printf("Guardando4:%s:\n",b4);
	//guardando informacion
	settime();
	sprintf(new_inodo.i_date_mod,"%s", fecha);
	sprintf(new_inodo.i_ctime, "%s", fecha);
	sprintf(new_inodo.Llave,"%d", pi);
	sprintf(new_inodo.i_tam_archivo,"%d", getsize(informacion));
	sprintf(new_inodo.i_asig_bloques,"%d", bandera);
	sprintf(new_inodo.i_time_last_access, "%s", "00/00/0000 00:00");
	//
	mpi[pi-1]=1;
	mpb[pb-1]=1;
	struct struct_bloque bloque1=EXT3obtener_bloque(pb, tdisco, activa);
	struct struct_bloque bloque2;
	struct struct_bloque bloque3;
	struct struct_bloque bloque4;
	int pb2=0;
	int pb3=0;
	int pb4=0;
	sprintf(bloque1.estado,"%d",1);
	sprintf(bloque1.data,"%s",b1);
	int usados=1;
	if(bandera>1){
		for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb2==0);ifor++){
			if(mpb[ifor]==0){
				pb2=ifor+1;
				mpb[ifor]=1;
			}
		}
		usados++;
		bloque2=EXT3obtener_bloque(pb2, tdisco, activa);
		sprintf(bloque2.estado,"%d",1);
		sprintf(bloque2.data,"%s",b2);
		if(bandera>2){
			for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb3==0);ifor++){
				if(mpb[ifor]==0){
					pb3=ifor+1;
					mpb[ifor]=1;
				}
			}
			usados++;
			bloque3=EXT3obtener_bloque(pb3, tdisco, activa);
			sprintf(bloque3.estado,"%d",1);
			sprintf(bloque3.data,"%s",b3);
			if(bandera>3){
				for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb4==0);ifor++){
					if(mpb[ifor]==0){
						pb4=ifor+1;
						mpb[ifor]=1;
					}
				}
				usados++;
				bloque4=EXT3obtener_bloque(pb4, tdisco, activa);
				sprintf(bloque4.estado,"%d",1);
				sprintf(bloque4.data,"%s",b4);
			}
		}
	}
	sprintf(new_inodo.i_block1,"%d", pb);
	sprintf(new_inodo.i_block2,"%d", pb2);
	sprintf(new_inodo.i_block3,"%d", pb3);
	sprintf(new_inodo.i_block4,"%d", pb4);
	sprintf(new_inodo.i_tipo,"%s", tipo);
	//actualizando la informacion
	sprintf(superbloque.sb_bloques_freee,"%d", atoi(superbloque.sb_bloques_freee)-usados);
	sprintf(superbloque.sb_inodos_free,"%d", atoi(superbloque.sb_inodos_free)-usados);
	//
	int tb=0;
	for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) && (tb==0);ifor++){
		if(mpb[ifor]==0){
			tb=ifor+1;
		}
	}
	int ti=0;
	for(ifor=0;(ifor<atoi(superbloque.sb_numero_inodos)) && (ti==0);ifor++){
		if(mpi[ifor]==0){
			ti=ifor+1;
		}
	}
	sprintf(superbloque.sb_first_free_bitmapbloque,"%d", tb);
	sprintf(superbloque.sb_fist_free_bitmapinodo,"%d", ti);
	//guardando
	fseek(f,mbr_address,SEEK_SET);
	fwrite(&superbloque, sizeof(superbloque), 1, f);
	fwrite(&mpi,sizeof(mpi),1,f);
	fwrite(&mpb,sizeof(mpb),1,f);
	fclose(f);
	EXT3guardar_bloque(pb, tdisco, bloque1, activa);
	if(bandera>1){
		EXT3guardar_bloque(pb2, tdisco, bloque2, activa);
		if(bandera>2){
			EXT3guardar_bloque(pb3, tdisco, bloque3, activa);
			if(bandera>3){
				EXT3guardar_bloque(pb4, tdisco, bloque4, activa);
			}
		}
	}
	if(bandera==5){
		sprintf(new_inodo.i_Iblock,"%d", EXT3guardar(tdisco, i1, tipo, activa));
	}
	//finalizando
	EXT3guardar_inodo(pi, tdisco, new_inodo, activa);
	return pi_usado;
}

void FATguardar(char *tinformacion, struct struct_disco tdisco, int activa){
	//printf("Recive->:%s\n", tinformacion);
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	//configurando datos
	char informacion[getsize(tinformacion)];
	sprintf(informacion, "%s", tinformacion);
	int size=getsize(informacion);
	char b1[51];
	for(ifor=0;ifor<51;ifor++)b1[ifor]=0;
	char *i1="";
	int bandera=0;
	for(ifor=0;ifor<size;ifor++){
		if(ifor<51){
			b1[ifor]=informacion[ifor];
			bandera=1;
		}else{
			int s=getsize(i1);
			char temporal3[s+1];
			sprintf(temporal3,"%s%c", i1, informacion[ifor]);
			i1=temporal3;
			bandera=2;
		}
	}
	//printf("Prueba1->:%s\n", i1);
	b1[51]=0;
	//printf("Prueba2->:%s\n", b1);
	int fd=atoi(boot.b_next_bloque_free);
	//buscando siguiente bloque libre
	sprintf(boot.b_bloques_free, "%d", atoi(boot.b_bloques_free)-1);
	sprintf(boot.b_bloques_count, "%d", atoi(boot.b_bloques_count)+1);
	int read=atoi(boot.b_ap_bloque_datos)+mbr_address;
	fseek(f,read,SEEK_SET);
	int ttotal=atoi(boot.b_bloques_free)+atoi(boot.b_bloques_count);
	int k=0;
	int libre=0;
	for(k=0;(k<ttotal) && (libre==0); k++){
		struct struct_datos tdatos;
		fread(&tdatos, sizeof(tdatos), 1, f);
		if((atoi(tdatos.disponible)==0) && (k+1)!=fd)
			libre=k+1;
	}
	
	char cerror[getsize(i1)];
	sprintf(cerror,"%s", i1);
	
	//printf("Prueba3->:%s\n", cerror);
	//printf("Prueba4->:%s\n", b1);
	
	sprintf(boot.b_next_bloque_free, "%d", libre);
	fseek(f,mbr_address,SEEK_SET);
	fwrite(&boot, sizeof(boot), 1, f);
	fclose(f);
	//guardando bloque
	struct struct_datos datos;
	sprintf(datos.disponible,"%d",1); //si esta libre =0, =1 ocupado
	sprintf(datos.bd_data,"%s",b1);//Contiene la información del archivo.51 Caracteres, 50caracteres + 1 de finalización
	sprintf(datos.bd_numero,"%d",fd);//Número de bloque de datos
	if(bandera==2){
		sprintf(datos.bd_ap_directo_siguiente,"%d",libre);//Apuntador Número de bloque siguiente que contiene información o número de byte.
	}else{
		sprintf(datos.bd_ap_directo_siguiente,"%d",0);//Apuntador Número de bloque siguiente que contiene información o número de byte.
	}
	FATguardar_datos(fd, tdisco, datos, activa);
	//printf("Prueba5->:%s\n", cerror);
	//printf("Guardando->:%d:->:%s\n", fd, b1);
	if(bandera==2){
		//printf("Envia->:%s\n", cerror);
		FATguardar(i1, tdisco, activa);
	}
}

//guarda la informacion
void EXT3editar(char *informacion, struct struct_disco tdisco, int illave, int activa){
	//obteniendo el Inodo
	struct struct_inodo inodo=EXT3obtener_inodo(illave, tdisco, activa);
	//aqui, se elimina el inodo anterior con todos sus bloques
	EXT3_delete_all("", illave, tdisco, activa, 0);
	//cargando informacion
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	struct struct_mbr mbr;
	fseek(f,(int)(sizeof(tdisco)),SEEK_SET);
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//obteniendo el mapa PI
	char mpi[atoi(superbloque.sb_numero_inodos)];
	fread(&mpi,sizeof(mpi),1,f);
	//obteniendo el mapa PB
	char mpb[atoi(superbloque.sb_numero_bloques)];
	fread(&mpb,sizeof(mpb),1,f);
	//configurando inodo
	int size=getsize(informacion);
	char *i1="";
	char b4[64];
	for(ifor=0;ifor<64;ifor++)b4[ifor]=0;
	char b3[64];
	for(ifor=0;ifor<64;ifor++)b3[ifor]=0;
	char b2[64];
	for(ifor=0;ifor<64;ifor++)b2[ifor]=0;
	char b1[64];
	for(ifor=0;ifor<64;ifor++)b1[ifor]=0;
	int bandera=0;
	//printf("Guardando1:%s:\n",b1);
	//printf("Guardando2:%s:\n",b2);
	//printf("Guardando3:%s:\n",b3);
	//printf("Guardando4:%s:\n",b4);
	for(ifor=0;ifor<size;ifor++){
		if(ifor<64){
			b1[ifor]=informacion[ifor];
			//printf("-->1:%s:\n",b1);
			bandera=1;
		}else if(ifor<128){
			b2[ifor-64]=informacion[ifor];
			//printf("-->12:%s:\n",b1);
			bandera=2;
		}else if(ifor<192){
			b3[ifor-128]=informacion[ifor];
			//printf("-->13:%s:\n",b1);
			bandera=3;
		}else if(ifor<256){
			b4[ifor-192]=informacion[ifor];
			//printf("-->14:%s:\n",b1);
			bandera=4;
		}else{
			int s=getsize(i1);
			char temporal3[s+1];
			sprintf(temporal3,"%s%c", i1, informacion[ifor]);
			i1=temporal3;
			bandera=5;
		}
	}
	switch(bandera){
		case 2: 
			b1[getsize(b1)-3]=0;
		break;
		case 3: 
			b1[getsize(b1)-3]=0;
			b2[getsize(b2)]=0;
		break;
		case 4: 
			b1[getsize(b1)-3]=0;
			b2[getsize(b2)]=0;
			b3[getsize(b3)]=0;
		break;
		case 5: 
			b1[getsize(b1)-3]=0;
			b2[getsize(b2)]=0;
			b3[getsize(b3)]=0;
			b4[getsize(b4)]=0;
		break;
	}
	//printf("Guardando1:%s:\n",b1);
	//printf("Guardando2:%s:\n",b2);
	//printf("Guardando3:%s:\n",b3);
	//printf("Guardando4:%s:\n",b4);
	//guardando informacion
	settime();
	sprintf(inodo.i_date_mod,"%s", fecha);
	sprintf(inodo.i_tam_archivo,"%d", getsize(informacion));
	sprintf(inodo.i_asig_bloques,"%d", bandera);
	sprintf(inodo.i_block2,"%d", 0);
	sprintf(inodo.i_block3,"%d", 0);
	sprintf(inodo.i_block4,"%d", 0);
	sprintf(inodo.i_Iblock,"%d", 0);
	//
	int pb=atoi(inodo.i_block1);
	mpb[pb]=1;
	mpb[illave]=1;
	struct struct_bloque bloque1=EXT3obtener_bloque(pb, tdisco, activa);
	struct struct_bloque bloque2;
	struct struct_bloque bloque3;
	struct struct_bloque bloque4;
	int pb2=0;
	int pb3=0;
	int pb4=0;
	sprintf(bloque1.estado,"%d",1);
	sprintf(bloque1.data,"%s",b1);
	int usados=1;
	if(bandera>1){
		for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb2==0);ifor++){
			if(mpb[ifor]==0){
				pb2=ifor+1;
				mpb[ifor]=1;
			}
		}
		usados++;
		bloque2=EXT3obtener_bloque(pb2, tdisco, activa);
		sprintf(bloque2.estado,"%d",1);
		sprintf(bloque2.data,"%s",b2);
		if(bandera>2){
			for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb3==0);ifor++){
				if(mpb[ifor]==0){
					pb3=ifor+1;
					mpb[ifor]=1;
				}
			}
			usados++;
			bloque3=EXT3obtener_bloque(pb3, tdisco, activa);
			sprintf(bloque3.estado,"%d",1);
			sprintf(bloque3.data,"%s",b3);
			if(bandera>3){
				for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb4==0);ifor++){
					if(mpb[ifor]==0){
						pb4=ifor+1;
						mpb[ifor]=1;
					}
				}
				usados++;
				bloque4=EXT3obtener_bloque(pb4, tdisco, activa);
				sprintf(bloque4.estado,"%d",1);
				sprintf(bloque4.data,"%s",b4);
			}
		}
	}
	sprintf(inodo.i_block1,"%d", pb);
	sprintf(inodo.i_block2,"%d", pb2);
	sprintf(inodo.i_block3,"%d", pb3);
	sprintf(inodo.i_block4,"%d", pb4);
	sprintf(inodo.i_tipo,"%s", "file");
	//actualizando la informacion
	sprintf(superbloque.sb_bloques_freee,"%d", atoi(superbloque.sb_bloques_freee)-usados);
	sprintf(superbloque.sb_inodos_free,"%d", atoi(superbloque.sb_inodos_free)-usados);
	//
	int tb=0;
	for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) && (tb==0);ifor++){
		if(mpb[ifor]==0){
			tb=ifor+1;
		}
	}
	int ti=0;
	for(ifor=0;(ifor<atoi(superbloque.sb_numero_inodos)) && (ti==0);ifor++){
		if(mpi[ifor]==0){
			ti=ifor+1;
		}
	}
	sprintf(superbloque.sb_first_free_bitmapbloque,"%d", tb);
	sprintf(superbloque.sb_fist_free_bitmapinodo,"%d", ti);
	//guardando
	fseek(f,mbr_address,SEEK_SET);
	fwrite(&superbloque, sizeof(superbloque), 1, f);
	fwrite(&mpi,sizeof(mpi),1,f);
	fwrite(&mpb,sizeof(mpb),1,f);
	fclose(f);
	EXT3guardar_bloque(pb, tdisco, bloque1, activa);
	if(bandera>1){
		EXT3guardar_bloque(pb2, tdisco, bloque2, activa);
		if(bandera>2){
			EXT3guardar_bloque(pb3, tdisco, bloque3, activa);
			if(bandera>3){
				EXT3guardar_bloque(pb4, tdisco, bloque4, activa);
			}
		}
	}
	if(bandera==5){
		sprintf(inodo.i_Iblock,"%d", EXT3guardar(tdisco, i1, "file", activa));
	}
	//finalizando
	EXT3guardar_inodo(illave, tdisco, inodo, activa);
}

void FATeditar(char *informacion, struct struct_disco tdisco, int nivel, char padre[50], int activa, int apuntador){
	//-------------------------------
	//buscando tabla para actualizarla
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f,mbr_address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	int tfree=atoi(boot.b_tablas_free);
	int tcount=atoi(boot.b_tablas_count);
	int ttotal=tfree+tcount;
	//printf("%d-%d-%d\n", tfree, tcount, ttotal);
	int k=0;
	int leidos=0;
	int encontrado=0;
	//arreglos para la funcion
	nivel--;
	//printf("buscando:%d:%s:\n",nivel,padre);
	for(k=0;(k<ttotal) && (leidos<tcount) && encontrado==0 && k<40; k++){
	//for(k=0;(k<10); k++){
		struct struct_tabla tabla;
		fread(&tabla, sizeof(tabla), 1, f);
		//printf("leyendo:%s:%s:%s:\n",tabla.lista_nombre,tabla.lista_nivel,tabla.lista_nombre_padre);
		//printf("tabla %d disponible:%d\n",k, atoi(tabla.disponible));
		//printf("tabla nivel:%d\n", atoi(tabla.lista_nivel));
		if(atoi(tabla.disponible)==1){
			leidos++;
			//printf("tabla.lista_nombre_padre:%s:(atoi(tabla.lista_nivel):%s==nivel:%d) && (strcmp(tabla.lista_nombre:%s,padre:%s)==0) && (apuntador:%d==atoi(tabla.lista_ap_directo_bloque):%s)\n",tabla.lista_nombre_padre, tabla.lista_nivel, nivel, tabla.lista_nombre, padre, apuntador, tabla.lista_ap_directo_bloque);
			if((atoi(tabla.lista_nivel)==nivel) && (strcmp(tabla.lista_nombre,padre)==0) && (apuntador==atoi(tabla.lista_ap_directo_bloque))){
				settime();
				sprintf(tabla.lista_fecha_modificacion,"%s", fecha);
				FATguardar_tabla(k+1, tdisco, tabla, activa);
				encontrado=k+1;
			}
		}
	}
	fclose(f);
	//-------------------------------
	//obteniendo tabla
	struct struct_tabla ttabla=FATobtener_tabla(encontrado, tdisco, activa);
	//eliminando informacion anterior
	FAT_delete_all_data(atoi(ttabla.lista_ap_directo_bloque), tdisco, activa);
	//FAT_delete_all_tabla("", atoi(ttabla.lista_nivel), atoi(ttabla.lista_ap_directo_bloque), ttabla.lista_nombre_padre, tdisco, activa, 0);
	//actualizando informacion
	//printf("ACTUALIZADO:%s\n",ttabla.lista_nombre);
	//printf("ACTUALIZADO:%s\n",ttabla.lista_nombre_padre);
	//printf("ACTUALIZADO:%s\n",ttabla.lista_fecha_creacion);
	//printf("ACTUALIZADO:%s\n",ttabla.lista_fecha_modificacion);
	//FATguardar_tabla(encontrado, tdisco, ttabla, activa);
	//guardando bloques con informacion
	//engañando al boot para guardar en el apuntador especificado
	f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	fread(&mbr, sizeof(mbr), 1, f);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f,mbr_address,SEEK_SET);
	fread(&boot, sizeof(boot), 1, f);
	sprintf(boot.b_next_bloque_free, "%d", apuntador);
	fseek(f,mbr_address,SEEK_SET);
	fwrite(&boot, sizeof(boot), 1, f);
	fclose(f);
	//guardando de nuevo el bloque
	FATguardar(informacion, tdisco, activa);
	//finalizo
}

//recive el contenido de un folder y el archivo o carpeta a eliminar, despues lo elimina y devuelve el contenido sin lo eliminado
char* EXT3eliminar(char tipo[4], char *original, char nombre[50], struct struct_disco tdisco, int activa, char tubicacion[640]){
	//analizando cadena recivida
	char informacion[getsize(original)];
	int t=0; for(t=0;t<getsize(original);t++)informacion[t]=0;
	char regresar[getsize(original)];
	sprintf(regresar,"%s", "");
	sprintf(informacion,"%s", original);
	//buscando el id seleccionado
	int k=0;
	int activar=0;
	char id[7];
	char id_eliminar[7];
	char ubicacion[640];
	char ubicacion_eliminar[640];
	int opcion=1;
	int iniword=0;
	int inicio=0;
	for(k=0;(k<getsize(informacion)) & (informacion[k]!=0);k++){
		if(informacion[k]==10){
			activar=0;
			opcion++;
			iniword=0;
			if(strcmp(ubicacion,nombre)==0){
				sprintf(id_eliminar, "%s", id);
				sprintf(ubicacion_eliminar, "%s", ubicacion);
			}else{
				if(inicio==0){
					inicio=1;
					sprintf(regresar, "%s %s\n", ubicacion, id);
				}else
					sprintf(regresar, "%s%s %s\n", regresar, ubicacion, id);
			}
		}
		if(activar==1){
			if(informacion[k-1]==32)
				sprintf(id, "%c", informacion[k]);
			else
				sprintf(id, "%s%c", id, informacion[k]);
		}
		if(informacion[k]==32){
			activar=1;
		}
		if((informacion[k]!=10) & (activar==0)){
			if(iniword==0){
				sprintf(ubicacion, "%c", informacion[k]);
				iniword=1;
			}else
				sprintf(ubicacion, "%s%c", ubicacion, informacion[k]);
		}
	}
	//se tiene el numero de inodo:id, y el nombre de archivo o folder:ubicacion
	if((strcmp(ubicacion_eliminar,nombre)==0) && (strcmp(id_eliminar,"")!=0)){
		//obteniendo inodo
		struct struct_inodo inodo=EXT3obtener_inodo(atoi(id_eliminar), tdisco, activa);
		if(strcmp(tipo, "dir")==0){
			if(strcmp(inodo.i_tipo, "dir")==0){
				sprintf(ubicacion_eliminar,"%s/", ubicacion_eliminar);
				
				char copy2[getsize(ubicacion_eliminar)];
				sprintf(copy2,"%s", ubicacion_eliminar);
				char *taccion="Carpeta eliminada: ";
				char accion[getsize(taccion)+getsize(copy2)];
				sprintf(accion,"%s%s", taccion, copy2);
				if(activa==1)
					Bitacora_registro("Eliminar carpeta", 1, tubicacion, accion, tdisco, activa);
				else
					Bitacora_registro("COPIA:Eliminar carpeta", 1, tubicacion, accion, tdisco, activa);
				
				EXT3_delete_all(ubicacion_eliminar, atoi(inodo.Llave), tdisco, activa, 1);
				if(activa!=0)
					printf("Se elimino la carpeta correctamente\n");
			}else{
				if(activa!=0)
					printf("La seleccion es un archivo, ERROR!\n");
				sprintf(regresar,"%s", original);
			}
		}else{
			if(strcmp(inodo.i_tipo, "file")==0){
				
				char copy2[getsize(ubicacion_eliminar)];
				sprintf(copy2,"%s", ubicacion_eliminar);
				char *taccion="Archivo eliminado: ";
				char accion[getsize(taccion)+getsize(copy2)];
				sprintf(accion,"%s%s", taccion, copy2);
				if(activa==1)
					Bitacora_registro("Eliminar archivo", 0, tubicacion, accion, tdisco, activa);
				else
					Bitacora_registro("COPIA:Eliminar archivo", 0, tubicacion, accion, tdisco, activa);
						
				EXT3_delete_all(ubicacion_eliminar, atoi(inodo.Llave), tdisco, activa, 1);
				if(activa!=0)
					printf("Se elimino el archivo correctamente\n");
			}else{
				sprintf(regresar,"%s", original);
				if(activa!=0)
					printf("La seleccion es una carpeta, ERROR!\n");
			}
		}
		//printf("Encontrado: %s, %s\n", ubicacion_eliminar, id_eliminar);
	}else{
		if(strcmp(tipo, "dir")==0){
			if(activa!=0)
				printf("Directorio no existe\n");
		}else{
			if(activa!=0)
				printf("Archivo no existe\n");
		}
	}
	//printf("Regresando:%s:::::::::\n", regresar);
	char *rtn=regresar;
	return rtn;
}

char* EXT3renombrar(char *original, char nombre[50], char renombre[50], struct struct_disco tdisco, int activa, char tubicacion[640]){
	//analizando cadena recivida
	//printf("->ANALIZANDO:%s\n",original);
	char informacion[getsize(original)];
	int t=0; for(t=0;t<getsize(original);t++)informacion[t]=0;
	char regresar[getsize(original)];
	sprintf(informacion,"%s", original);
	//buscando el id seleccionado
	int k=0;
	int activar=0;
	char id[7];
	int opcion=1;
	int iniword=0;
	int inicio=0;
	char ubicacion[640];
	int encontrado=0;
	//printf("->ANALIZANDO:%s\n",informacion);
	for(k=0;(k<getsize(informacion)) & (informacion[k]!=0);k++){
		if(informacion[k]==10){
			activar=0;
			opcion++;
			iniword=0;
			//printf("COMPARANDO::%s==%s::\n",ubicacion, nombre);
			if(strcmp(ubicacion,nombre)==0){
				//-- encontro el archivo
				struct struct_inodo einodo=EXT3obtener_inodo(atoi(id), tdisco, activa);
				//printf("INODO ID:%s\n",einodo.i_tipo);
				//printf("REGRESAR:%s\n",regresar);
				if(strcmp(einodo.i_tipo, "file")==0){
					if(inicio==0){
						inicio=1;
						sprintf(regresar, "%s %s\n", renombre, id);
					}else
						sprintf(regresar, "%s%s %s\n", regresar, renombre, id);
					char accion[getsize("nuevo nombre: ")+getsize(renombre)];
					sprintf(accion,"%s%s", "nuevo nombre: ", renombre);
					if(activa==1)
						Bitacora_registro("Renombrar archivo", 0, tubicacion, accion, tdisco, activa);
					else
						Bitacora_registro("COPIA:Renombrar archivo", 0, tubicacion, accion, tdisco, activa);
					if(activa!=0)
						printf("Se renombro el archivo correctamente\n");
				}else{
					if(inicio==0){
						inicio=1;
						sprintf(regresar, "%s %s\n", ubicacion, id);
					}else
						sprintf(regresar, "%s%s %s\n", regresar, ubicacion, id);
					if(activa!=0)
						printf("La seleccion es una carpeta, ERROR!\n");
				}
				//printf("REGRESAR:%s\n",regresar);
				encontrado=1;
				//-- termino la edicion
			}else{
				if(inicio==0){
					inicio=1;
					sprintf(regresar, "%s %s\n", ubicacion, id);
				}else
					sprintf(regresar, "%s%s %s\n", regresar, ubicacion, id);
			}
		}
		if(activar==1){
			if(informacion[k-1]==32)
				sprintf(id, "%c", informacion[k]);
			else
				sprintf(id, "%s%c", id, informacion[k]);
		}
		if(informacion[k]==32){
			activar=1;
		}
		if((informacion[k]!=10) & (activar==0)){
			if(iniword==0){
				sprintf(ubicacion, "%c", informacion[k]);
				iniword=1;
			}else
				sprintf(ubicacion, "%s%c", ubicacion, informacion[k]);
		}
	}
	//printf("Regresando:%s:::::::::\n", regresar);
	if(encontrado==0)
		printf("Archivo no existe\n");
	char *rtn=regresar;
	return rtn;
}

//si el nombre esta repetido
int EXT3repetido_carpeta_folder(char ubicacion[640], int llave, struct struct_disco tdisco, char busqueda[50]){
	int repetido=0;
	//actualizando inodo
	struct struct_inodo inodo=EXT3obtener_inodo(llave, tdisco, 1);
	//printf("Reading:%d:%s\n",llave,inodo.i_tipo);
	if(strcmp(inodo.i_tipo,"dir")==0){
		char *empty="";
		char temporal1[getsize(EXT3loaddata(empty, tdisco, inodo, 1))];
		sprintf(temporal1,"%s",EXT3loaddata(empty, tdisco, inodo, 1));
		char *informacion=temporal1;
		int k=0;
		int contador=1;
		int linea=0;
		int escribiendo=1;
		//busquda
		int bbool=1;
		int bmax=getsize(busqueda);
		int bindex=0;
		//fin
		for(k=0;(k<getsize(informacion)) & ((informacion[k]!=0) || (informacion[k]!=127));k++){
			if(linea==0){
				linea=1;
			}
			if(informacion[k]==32){
				escribiendo=0;
			}else if(informacion[k]==10){
				escribiendo=1;
				contador++;
				//printf("\n");
				struct struct_inodo_ubicacion inodo_ubicacion=EXT3get_inodo_from_seleccion(contador-1, inodo, tdisco, 1);
				char seleccion[640];
				//muestra de nuevo las opciones
				if(atoi(inodo_ubicacion.inodo.Llave)!=atoi(inodo.Llave)){
					if(strcmp(inodo_ubicacion.inodo.i_tipo,"dir")==0)
						sprintf(seleccion,"%s%s/", ubicacion, inodo_ubicacion.ubicacion);
					else
						sprintf(seleccion,"%s%s", ubicacion, inodo_ubicacion.ubicacion);
					//entra a la ubicacion
				}
				if(bbool==1){
					//----------------------------------------------
					inodo=EXT3obtener_inodo(atoi(inodo_ubicacion.inodo.Llave), tdisco, 1);
					//printf("Reading:%d:%s\n",llave,inodo.i_tipo);
					/*if(strcmp(inodo.i_tipo,"dir")==0 && buscar_carpeta==1){
						repetido=1;
						printf("La carpeta ya existe!\n");
					}else if(strcmp(inodo.i_tipo,"dir")!=0 && buscar_carpeta==0){
						repetido=1;
						printf("El archivo ya existe!\n");
					}*/
					repetido=1;
					printf("*********\nEl nombre ya esta en uso!\n*********\n");
					bindex=0;
				}
				bbool=1;
				linea=0;
			}else if(escribiendo==1){
				//printf("comparacion:%d:%d\n",bindex,bbool);
				if(bindex<bmax){
					if((informacion[k]==busqueda[bindex]) && (bbool==1)){
						bindex++;
					}else{
						bbool=0;
						bindex=0;
					}
				}else
					bbool=0;
				//printf("%c",informacion[k]);
			}
		}
	}
	//salida
	if(repetido==1){
		printf("Enter para continuar\n");
		char c;
		scanf("%c",&c);
		getchar();
	}
	return repetido;
}

//si el nombre esta repetido
int FATrepetido_carpeta_folder(char ubicacion[640], int nivel, int apuntador, char padre[50], struct struct_disco tdisco, char busqueda[50]){
	int repetido=0;
	if(apuntador==-1){
		//folder
		set_disco(tdisco.nombre);
		FILE *f = fopen (directorio, "rb+");
		fseek(f,sizeof(tdisco),SEEK_SET);
		struct struct_mbr mbr;
		fread(&mbr, sizeof(mbr), 1, f);
		fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		int tfree=atoi(boot.b_tablas_free);
		int tcount=atoi(boot.b_tablas_count);
		int ttotal=tfree+tcount;
		//printf("%d-%d-%d\n", tfree, tcount, ttotal);
		int k=0;
		int leidos=0;
		int contador=1;
		//printf("buscando:%d:%s:\n",nivel,padre);
		for(k=0;(k<ttotal) && (leidos<tcount); k++){
			struct struct_tabla tabla;
			fread(&tabla, sizeof(tabla), 1, f);
			if(atoi(tabla.disponible)==1){
				leidos++;
				if((atoi(tabla.lista_nivel)==nivel) && strcmp(tabla.lista_nombre_padre,padre)==0){
					struct struct_tabla tabla=FATget_tabla_from_seleccion(contador, nivel, padre, tdisco, 1);
					//int new_apuntador=atoi(tabla.lista_ap_directo_bloque);
					char seleccion[640];
					if(strcmp(tabla.lista_tipo,"dir")==0)
						sprintf(seleccion,"%s%s/", ubicacion, tabla.lista_nombre);
					else
						sprintf(seleccion,"%s%s", ubicacion, tabla.lista_nombre);
					if(strcmp(tabla.lista_nombre,busqueda)==0){
						/*if(new_apuntador==-1 && buscar_carpeta==1){
							//carpeta
							repetido=1;
							printf("La carpeta ya existe!\n");
						}else if(new_apuntador!=-1 && buscar_carpeta==0){
							//archivo
							repetido=1;
							printf("El archivo ya existe!\n");
						}*/
						repetido=1;
						printf("*********\nEl nombre ya esta en uso!\n*********\n");
					}
					//entrando
					contador++;
				}
			}
		}
		fclose(f);
	}
	//salida
	if(repetido==1){
		printf("Enter para continuar\n");
		char c;
		scanf("%c",&c);
		getchar();
	}
	return repetido;
}

//guarda la informacion
void EXT3actualiza(char *informacion, struct struct_disco tdisco, char tipo[4], int illave, int activa){
	//---
	//printf("\nEXT3actualiza.informacion:%s\n",print(informacion));
	//printf("EXT3actualiza.tipo:%s\n",print(tipo));
	//printf("EXT3actualiza.illave:%d\n",illave);
	//---
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//obteniendo el mapa PI
	char mpi[atoi(superbloque.sb_numero_inodos)];
	fread(&mpi,sizeof(mpi),1,f);
	//obteniendo el mapa PB
	char mpb[atoi(superbloque.sb_numero_bloques)];
	fread(&mpb,sizeof(mpb),1,f);
	//obteniendo el Inodo
	struct struct_inodo inodo=EXT3obtener_inodo(illave, tdisco, activa);
	int pb=atoi(inodo.i_block1);
	//---
	//printf("\nEXT3actualiza2.informacion:%s\n",print(informacion));
	//printf("EXT3actualiza2.tipo:%s\n",print(tipo));
	//printf("EXT3actualiza2.illave:%d\n",illave);
	//printf("EXT3actualiza2.inodo.Llave:%s\n",inodo.Llave);
	//printf("EXT3actualiza2.pb:%d\n",pb);
	//---
	//configurando inodo
	int size=getsize(informacion);
	char b1[64];
	for(ifor=0;ifor<64;ifor++)b1[ifor]=0;
	char b2[64];
	for(ifor=0;ifor<64;ifor++)b2[ifor]=0;
	char b3[64];
	for(ifor=0;ifor<64;ifor++)b3[ifor]=0;
	char b4[64];
	for(ifor=0;ifor<64;ifor++)b4[ifor]=0;
	char *i1="";
	int bandera=0;
	for(ifor=0;ifor<size;ifor++){
		if(ifor<64){
			b1[ifor]=informacion[ifor];
			bandera=1;
		}else if(ifor<128){
			b2[ifor-64]=informacion[ifor];
			bandera=2;
		}else if(ifor<192){
			b3[ifor-128]=informacion[ifor];
			bandera=3;
		}else if(ifor<256){
			b4[ifor-192]=informacion[ifor];
			bandera=4;
		}else{
			char temp[64];
			for(ifor=0;ifor<64;ifor++)temp[ifor]=0;
			sprintf(temp, "%c", informacion[ifor]);
			i1=cargarinformacion(i1,temp);
			bandera=5;
		}
	}
	//guardando informacion
	settime();
	sprintf(inodo.i_date_mod,"%s", fecha);
	sprintf(inodo.i_tam_archivo,"%d", getsize(informacion));
	sprintf(inodo.i_asig_bloques,"%d", bandera);
	//
	struct struct_bloque bloque1=EXT3obtener_bloque(atoi(inodo.i_block1), tdisco, activa);
	struct struct_bloque bloque2;
	if(atoi(inodo.i_block2)!=0)
		bloque2=EXT3obtener_bloque(atoi(inodo.i_block2), tdisco, activa);
	struct struct_bloque bloque3;
	if(atoi(inodo.i_block3)!=0)
		bloque3=EXT3obtener_bloque(atoi(inodo.i_block3), tdisco, activa);
	struct struct_bloque bloque4;
	if(atoi(inodo.i_block4)!=0)
		bloque4=EXT3obtener_bloque(atoi(inodo.i_block4), tdisco, activa);
	//antes de actualizar, marcando como vacio
	sprintf(bloque2.estado,"%d",0);
	sprintf(bloque3.estado,"%d",0);
	sprintf(bloque4.estado,"%d",0);
	fclose(f);
	if(atoi(inodo.i_block2)!=0)
		EXT3guardar_bloque(atoi(inodo.i_block2), tdisco, bloque2, activa);
	if(atoi(inodo.i_block3)!=0)
		EXT3guardar_bloque(atoi(inodo.i_block3), tdisco, bloque3, activa);
	if(atoi(inodo.i_block4)!=0)
		EXT3guardar_bloque(atoi(inodo.i_block4), tdisco, bloque4, activa);
	//fin de marcado como vacio
	int pb2=0;
	int pb3=0;
	int pb4=0;
	sprintf(bloque1.estado,"%d",1);
	sprintf(bloque1.data,"%s",b1);
	int usados=0;
	if(bandera>1){
		if(atoi(inodo.i_block2)==0){
			for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb2==0);ifor++){
				if(mpb[ifor]==0){
					pb2=ifor+1;
					mpb[ifor]=1;
				}
			}
			usados++;
		}else{
			pb2=atoi(inodo.i_block2);
		}
		bloque2=EXT3obtener_bloque(pb2, tdisco, activa);
		sprintf(bloque2.estado,"%d",1);
		sprintf(bloque2.data,"%s",b2);
		if(bandera>2){
			if(atoi(inodo.i_block3)==0){
				for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb3==0);ifor++){
					if(mpb[ifor]==0){
						pb3=ifor+1;
						mpb[ifor]=1;
					}
				}
				usados++;
			}else{
				pb3=atoi(inodo.i_block3);
			}
			bloque3=EXT3obtener_bloque(pb3, tdisco, activa);
			sprintf(bloque3.estado,"%d",1);
			sprintf(bloque3.data,"%s",b3);
			if(bandera>3){
				if(atoi(inodo.i_block4)==0){
					for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) & (pb4==0);ifor++){
						if(mpb[ifor]==0){
							pb4=ifor+1;
							mpb[ifor]=1;
						}
					}
					usados++;
				}else{
					pb4=atoi(inodo.i_block4);
				}
				bloque4=EXT3obtener_bloque(pb4, tdisco, activa);
				sprintf(bloque4.estado,"%d",1);
				sprintf(bloque4.data,"%s",b4);
			}
		}
	}
	sprintf(inodo.i_block1,"%d", pb);
	sprintf(inodo.i_block2,"%d", pb2);
	sprintf(inodo.i_block3,"%d", pb3);
	sprintf(inodo.i_block4,"%d", pb4);
	//actualizando la informacion
	sprintf(superbloque.sb_bloques_freee,"%d", atoi(superbloque.sb_bloques_freee)-usados);
	sprintf(superbloque.sb_inodos_free,"%d", atoi(superbloque.sb_inodos_free)-usados);
	//
	int tb=0;
	for(ifor=0;(ifor<atoi(superbloque.sb_numero_bloques)) && (tb==0);ifor++){
		if(mpb[ifor]==0){
			tb=ifor+1;
		}
	}
	int ti=0;
	for(ifor=0;(ifor<atoi(superbloque.sb_numero_inodos)) && (ti==0);ifor++){
		if(mpi[ifor]==0){
			ti=ifor+1;
		}
	}
	sprintf(superbloque.sb_first_free_bitmapbloque,"%d", tb);
	sprintf(superbloque.sb_fist_free_bitmapinodo,"%d", ti);
	//guardando
	set_disco(tdisco.nombre);
	f = fopen (directorio, "rb+");
	fseek(f,mbr_address,SEEK_SET);
	fwrite(&superbloque, sizeof(superbloque), 1, f);
	fwrite(&mpi,sizeof(mpi),1,f);
	fwrite(&mpb,sizeof(mpb),1,f);
	fclose(f);
	EXT3guardar_bloque(atoi(inodo.i_block1), tdisco, bloque1, activa);
	if(bandera>1){
		EXT3guardar_bloque(pb2, tdisco, bloque2, activa);
		if(bandera>2){
			EXT3guardar_bloque(pb3, tdisco, bloque3, activa);
			if(bandera>3){
				EXT3guardar_bloque(pb4, tdisco, bloque4, activa);
			}
		}
	}
	if(bandera==5){
		if(atoi(inodo.i_Iblock)==0)
			sprintf(inodo.i_Iblock,"%d", EXT3guardar(tdisco, i1, tipo, activa));
		else{
			EXT3actualiza(i1, tdisco, tipo, atoi(inodo.i_Iblock), activa);
		}
	}
	//finalizando
	EXT3guardar_inodo(atoi(inodo.Llave), tdisco, inodo, activa);
	//---
	//printf("\nEXT3actualiza3.bloque.data:%s\n",print(bloque1.data));
	//printf("EXT3actualiza3.inodo.i_bloque1:%s\n",inodo.i_block1);
	//printf("EXT3actualiza3.inodo.i_bloque2:%s\n",inodo.i_block2);
	//printf("EXT3actualiza3.inodo.i_bloque3:%s\n",inodo.i_block3);
	//printf("EXT3actualiza3.inodo.i_bloque4:%s\n",inodo.i_block4);
	//printf("EXT3actualiza3.inodo.i_ibloque5:%s\n",inodo.i_Iblock);
	//struct struct_inodo killing=EXT3obtener_inodo(atoi(inodo.Llave),tdisco);
	//struct struct_bloque inthename=EXT3obtener_bloque(atoi(killing.i_block1),tdisco);
	//printf("\nEXT3actualiza4.bloque.data:%s\n",print(inthename.data));
	//printf("EXT3actualiza4.inodo.i_bloque1:%s\n",killing.i_block1);
	//printf("EXT3actualiza4.inodo.i_bloque2:%s\n",killing.i_block2);
	//printf("EXT3actualiza4.inodo.i_bloque3:%s\n",killing.i_block3);
	//printf("EXT3actualiza4.inodo.i_bloque4:%s\n",killing.i_block4);
	//printf("EXT3actualiza4.inodo.i_ibloque5:%s\n",killing.i_Iblock);
	//FILE *fight = fopen (directorio, "rb+");
	//fseek(fight,sizeof(tdisco),SEEK_SET);
	//struct struct_mbr with;
	//fread(&with, sizeof(with), 1, fight);
	//fseek(fight,atoi(with.mbr_byte_particion),SEEK_SET);
	//struct struct_superbloque themachine;
	//fread(&themachine, sizeof(themachine), 1, fight);
	////obteniendo el mapa PI
	//char tellme[atoi(themachine.sb_numero_inodos)];
	//fread(&tellme,sizeof(tellme),1,fight);
	////obteniendo el mapa PB
	//char how[atoi(themachine.sb_numero_bloques)];
	//fread(&how,sizeof(how),1,fight);
	//printf("EXT3actualiza5.superbloque.freepi:%s\n",themachine.sb_fist_free_bitmapinodo);
	//printf("EXT3actualiza5.superbloque.freepb:%s\n",themachine.sb_first_free_bitmapbloque);
	//printf("EXT3actualiza5.mapapi:");
	//int powerback=0;
	//for(powerback=0;powerback<10;powerback++)
	//	printf("%d",tellme[powerback]);
	//printf("\n");
	//printf("EXT3actualiza5.mapapb:");
	//for(powerback=0;powerback<10;powerback++)
	//	printf("%d",how[powerback]);
	//printf("\n");
	//fclose(fight);
	//---
}

void EXT3_crear_carpeta(char nombre[50], struct struct_disco tdisco, int illave, int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr y superbloque
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//obteniendo el PI
	int pi=atoi(superbloque.sb_fist_free_bitmapinodo);
	fclose(f);
	char t[64];
	sprintf(t,". %d\n.. %d\n",pi, illave);
	char *informacion=t;
	//---
	//printf("GUARDANDO:%s\n",print(t));
	//---
	int pi_usado=EXT3guardar(tdisco, informacion, "dir", activa);
	//---
	//printf("GUARDADO:%d\n",pi_usado);
	//---
	sprintf(t,"%s %d\n",nombre, pi_usado);
	informacion=t;
	//---
	//printf("ACTUALIZARA:%s\n",print(t));
	//printf("ACTUALIZARA:%s\n",print(t));
	//---
	char *original="";
	original=EXT3loaddata(original, tdisco, EXT3obtener_inodo(illave, tdisco, activa), activa);
	//---
	//printf("ANTIGUO:%s\n",print(original));
	//printf("ANTIGUO:%s\n",print(original));
	//---
	char temporal1[getsize(original)];
	sprintf(temporal1,"%s",original);
	char temporal2[getsize(original)+getsize(t)];
	sprintf(temporal2,"%s%s",temporal1,t);
	char *guardar=temporal2;
	//---
	//printf("GUARDANDO1:%s\n",print(original));
	//printf("GUARDANDO2:%s\n",print(t));
	//printf("FINALMENTE SE GUARDARA:%s\n",print(guardar));
	//---
	EXT3actualiza(guardar, tdisco, "dir", illave, activa);
}

void EXT3_eliminar_carpeta(char nombre[50], struct struct_disco tdisco, int illave, int activa, char tubicacion[640]){
	//obteniendo el inodo
	struct struct_inodo inodo=EXT3obtener_inodo(illave, tdisco, activa);
	//obteniendo contenido de carpeta
	char *original="";
	original=EXT3loaddata(original, tdisco, inodo, activa);
	char actualizar[getsize(original)];
	sprintf(actualizar, "%s", EXT3eliminar("dir", original, nombre, tdisco, activa, tubicacion));
	//printf("obtenido:\n%s:::::::::\n", actualizar);
	EXT3actualiza(actualizar, tdisco, "dir", atoi(inodo.Llave), activa);
}

void EXT3_eliminar_archivo(char nombre[50], struct struct_disco tdisco, int illave, int activa, char tubicacion[640]){
	//obteniendo el inodo
	struct struct_inodo inodo=EXT3obtener_inodo(illave, tdisco, activa);
	//obteniendo contenido de carpeta
	char *original="";
	original=EXT3loaddata(original, tdisco, inodo, activa);
	char actualizar[getsize(original)];
	sprintf(actualizar, "%s", EXT3eliminar("file", original, nombre, tdisco, activa, tubicacion));
	//printf("obtenido:\n%s:::::::::\n", actualizar);
	EXT3actualiza(actualizar, tdisco, "dir", atoi(inodo.Llave), activa);
}

void EXT3_renombrar_archivo(char nombre[50], char renombre[50], struct struct_disco tdisco, int illave, int activa, char tubicacion[640]){
	//obteniendo el inodo
	struct struct_inodo inodo=EXT3obtener_inodo(illave, tdisco, activa);
	//obteniendo contenido de carpeta
	char *original="";
	original=EXT3loaddata(original, tdisco, inodo, activa);
	char cerror[getsize(original)];
	sprintf(cerror, "%s", original);
	//printf("ENVIANDO:%s:\n", cerror);
	char actualizar[getsize(original)];
	sprintf(actualizar, "%s", EXT3renombrar(cerror, nombre, renombre, tdisco, activa, tubicacion));
	//printf("obtenido:\n%s:::::::::\n", actualizar);
	EXT3actualiza(actualizar, tdisco, "dir", atoi(inodo.Llave), activa);
}

void FAT_crear_carpeta(char nombre[50], struct struct_disco tdisco, int nivel, char padre[4], int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr y superbloque
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	//obteniendo el siguiente tabla libre
	int ft=atoi(boot.b_next_tabla_free);
	//printf("::::::Escribiendo folder en tabla:%d:id:%d:\n",address, ft);
	//obteniendo el siguiente bloque libre
	struct struct_tabla tabla;
	settime();
	sprintf(tabla.lista_fecha_creacion, "%s", fecha);//Fecha de creación dela carpeta oarchivoel formato de fecha: dd/mm/yyyy hh:mm
	sprintf(tabla.lista_fecha_modificacion, "%s", fecha);//Fecha de modificación dela carpeta o archivoel formato de fecha: dd/mm/yyyy hh:mm
	sprintf(tabla.disponible, "%d", 1); //si esta libre =0, =1 ocupado
	sprintf(tabla.lista_nombre, "%s", nombre);//Contiene el nombre de la carpeta o archivo
	sprintf(tabla.lista_tipo, "%s", "dir");//Para identificar si es una carpeta o archivo
	sprintf(tabla.lista_nombre_padre, "%s", padre);//Indica el nombre de la carpeta padre
	sprintf(tabla.lista_ap_directo_bloque, "%d", -1);//Apuntador al byte o al número de la estructura en donde inicia el bloque de datos que contiene la información del archivo. Null si es carpeta.
	sprintf(tabla.lista_nivel, "%d", nivel);//Número indicando el nivel de jerarquía, hasta un máximo de 4 niveles.
	fclose(f);
	FATguardar_tabla(ft, tdisco, tabla, activa);
	//actualizando informacion del boot
	f = fopen (directorio, "rb+");
	int read=atoi(boot.b_ap_bloque_tabla_indexada)+address;
	fseek(f,read,SEEK_SET);
	//buscando siguiente tabla libre
	sprintf(boot.b_tablas_free, "%d", atoi(boot.b_tablas_free)-1);
	sprintf(boot.b_tablas_count, "%d", atoi(boot.b_tablas_count)+1);
	int ttotal=atoi(boot.b_tablas_free)+atoi(boot.b_tablas_count);
	int k=0;
	int libre=0;
	for(k=0;(k<ttotal) && (libre==0); k++){
		struct struct_tabla ttabla;
		fread(&ttabla, sizeof(ttabla), 1, f);
		if((atoi(ttabla.disponible)==0) && ((k+1)!=ft))
			libre=k+1;
	}
	sprintf(boot.b_next_tabla_free, "%d", libre);
	fseek(f,address,SEEK_SET);
	fwrite(&boot, sizeof(boot), 1, f);
	fclose(f);
}

void FAT_eliminar_carpeta(char nombre[50], struct struct_disco tdisco, int nivel, char padre[4], int activa, char tubicacion[640]){
	//si existe carpeta
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f,mbr_address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	int tfree=atoi(boot.b_tablas_free);
	int tcount=atoi(boot.b_tablas_count);
	int ttotal=tfree+tcount;
	//printf("%d-%d-%d\n", tfree, tcount, ttotal);
	int k=0;
	int leidos=0;
	int encontrado=0;
	//printf("buscando:%d:%s:\n",nivel,padre);
	for(k=0;(k<ttotal) && (leidos<tcount); k++){
	//for(k=0;(k<10); k++){
		struct struct_tabla tabla;
		fread(&tabla, sizeof(tabla), 1, f);
		//printf("leyendo:%s:%s:%s:\n",tabla.lista_nombre,tabla.lista_nivel,tabla.lista_nombre_padre);
		//printf("tabla %d disponible:%d\n",k, atoi(tabla.disponible));
		//printf("tabla nivel:%d\n", atoi(tabla.lista_nivel));
		if(atoi(tabla.disponible)==1){
			leidos++;
			if((atoi(tabla.lista_nivel)==nivel) && strcmp(tabla.lista_nombre_padre,padre)==0){
				if(strcmp(tabla.lista_nombre, nombre)==0){
					if(atoi(tabla.lista_ap_directo_bloque)==-1){
						leidos=tcount+1;
						//entrando
						encontrado=1;
						char direccion[640];
						sprintf(direccion,"%s/", tabla.lista_nombre);
						char copy2[getsize(direccion)];
						sprintf(copy2,"%s", direccion);
						char *taccion="Carpeta eliminada: ";
						char accion[getsize(taccion)+getsize(copy2)];
						sprintf(accion,"%s%s", taccion, copy2);
						if(activa==1)
							Bitacora_registro("Eliminar carpeta", 1, tubicacion, accion, tdisco, activa);
						else
							Bitacora_registro("COPIA:Eliminar carpeta", 1, tubicacion, accion, tdisco, activa);
						FAT_delete_all_tabla(direccion, nivel+1, k+1, tabla.lista_nombre, tdisco, activa, 1);
						if(activa!=0)
							printf("Se elimino la carpeta correctamente\n");
					}else{
						if(activa!=0){
							printf("La seleccion es un archivo, ERROR!\n");
							encontrado=1;
						}
					}
				}
			}
		}
	}
	if((encontrado==0) && (activa!=0))
		printf("Directorio no existe\n");
	fclose(f);
}

void FAT_eliminar_archivo(char nombre[50], struct struct_disco tdisco, int nivel, char padre[4], int activa, char tubicacion[640]){
	//si existe archivo
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f,mbr_address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	int tfree=atoi(boot.b_tablas_free);
	int tcount=atoi(boot.b_tablas_count);
	int ttotal=tfree+tcount;
	//printf("%d-%d-%d\n", tfree, tcount, ttotal);
	int k=0;
	int leidos=0;
	int encontrado=0;
	//printf("buscando:%d:%s:\n",nivel,padre);
	for(k=0;(k<ttotal) && (leidos<tcount); k++){
	//for(k=0;(k<10); k++){
		struct struct_tabla tabla;
		fread(&tabla, sizeof(tabla), 1, f);
		//printf("leyendo:%s:%s:%s:\n",tabla.lista_nombre,tabla.lista_nivel,tabla.lista_nombre_padre);
		//printf("tabla %d disponible:%d\n",k, atoi(tabla.disponible));
		//printf("tabla nivel:%d\n", atoi(tabla.lista_nivel));
		if(atoi(tabla.disponible)==1){
			leidos++;
			if((atoi(tabla.lista_nivel)==nivel) && strcmp(tabla.lista_nombre_padre,padre)==0){
				if(strcmp(tabla.lista_nombre, nombre)==0){
					if(atoi(tabla.lista_ap_directo_bloque)!=-1){
						leidos=tcount+1;
						//entrando
						encontrado=1;
						char direccion[640];
						sprintf(direccion,"%s", tabla.lista_nombre);
						
						char copy2[getsize(direccion)];
						sprintf(copy2,"%s", direccion);
						char *taccion="Archivo eliminado: ";
						char accion[getsize(taccion)+getsize(copy2)];
						sprintf(accion,"%s%s", taccion, copy2);
						if(activa==1)
							Bitacora_registro("Eliminar archivo", 0, tubicacion, accion, tdisco, activa);
						else
							Bitacora_registro("COPIA:Eliminar archivo", 0, tubicacion, accion, tdisco, activa);
						
						FAT_delete_all_tabla(direccion, nivel+1, k+1, tabla.lista_nombre, tdisco, activa, 1);
						if(activa!=0)
							printf("Se elimino el archivo correctamente\n");
					}else{
						if(activa!=0){
							printf("La seleccion es una carpeta, ERROR!\n");
							encontrado=1;
						}
					}
				}
			}
		}
	}
	if((encontrado==0) && (activa!=0))
		printf("Archivo no existe\n");
	fclose(f);
}

void FAT_renombrar_archivo(char nombre[50], char renombre[50], struct struct_disco tdisco, int nivel, char padre[4], int activa, char tubicacion[640]){
	//si existe archivo
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f,mbr_address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	int tfree=atoi(boot.b_tablas_free);
	int tcount=atoi(boot.b_tablas_count);
	int ttotal=tfree+tcount;
	//printf("%d-%d-%d\n", tfree, tcount, ttotal);
	int k=0;
	int leidos=0;
	int encontrado=0;
	//printf("buscando:%d:%s:\n",nivel,padre);
	for(k=0;(k<ttotal) && (leidos<tcount); k++){
	//for(k=0;(k<10); k++){
		struct struct_tabla tabla;
		fread(&tabla, sizeof(tabla), 1, f);
		//printf("leyendo:%s:%s:%s:\n",tabla.lista_nombre,tabla.lista_nivel,tabla.lista_nombre_padre);
		//printf("tabla %d disponible:%d\n",k, atoi(tabla.disponible));
		//printf("tabla nivel:%d\n", atoi(tabla.lista_nivel));
		if(atoi(tabla.disponible)==1){
			leidos++;
			if((atoi(tabla.lista_nivel)==nivel) && strcmp(tabla.lista_nombre_padre,padre)==0){
				if(strcmp(tabla.lista_nombre, nombre)==0){
					if(atoi(tabla.lista_ap_directo_bloque)!=-1){
						leidos=tcount+1;
						//entrando
						encontrado=1;
						//sprintf(direccion,"%s", tabla.lista_nombre);
						sprintf(tabla.lista_nombre, "%s", renombre);
						FATguardar_tabla(k+1, tdisco, tabla, activa);
						char accion[getsize("nuevo nombre: ")+getsize(renombre)];
						sprintf(accion,"%s%s", "nuevo nombre: ", renombre);
						if(activa==1)
							Bitacora_registro("Renombrar archivo", 0, tubicacion, accion, tdisco, activa);
						else
							Bitacora_registro("COPIA:Renombrar archivo", 0, tubicacion, accion, tdisco, activa);
						if(activa!=0)
							printf("Se renombro el archivo correctamente\n");
					}else{
						if(activa!=0){
							printf("La seleccion es una carpeta, ERROR!\n");
							encontrado=1;
						}
					}
				}
			}
		}
	}
	if((encontrado==0) && (activa!=0))
		printf("Archivo no existe\n");
	fclose(f);
}

void EXT3_crear_archivo(char nombre[50], char *informacion, struct struct_disco tdisco, int illave, int activa){
	int new_pi=EXT3guardar(tdisco, informacion, "file", activa);
	//printf("GUARDADO:%d\n",new_pi);
	//actualizando informacion en directorio
	char t[64];
	sprintf(t,"%s %d\n",nombre, new_pi);
	char *original="";
	original=EXT3loaddata(original, tdisco, EXT3obtener_inodo(illave, tdisco, activa), activa);
	char temporal1[getsize(original)];
	sprintf(temporal1,"%s",original);
	char temporal2[getsize(original)+getsize(t)];
	sprintf(temporal2,"%s%s",temporal1,t);
	char *guardar=temporal2;
	EXT3actualiza(guardar, tdisco, "file", illave, activa);
}

void FAT_crear_archivo(char nombre[50], char *informacion, struct struct_disco tdisco, int nivel, char padre[50], int activa){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr y superbloque
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	if(activa==0)
		mbr_address=atoi(mbr.mbr_byte_particion_desactivada);
	fseek(f, mbr_address, SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	//obteniendo el siguiente tabla libre
	int ft=atoi(boot.b_next_tabla_free);
	//obteniendo el siguiente bloque libre
	int fd=atoi(boot.b_next_bloque_free);
	//
	//guardando informacion en tablas
	struct struct_tabla tabla;
	settime();
	sprintf(tabla.lista_fecha_creacion, "%s", fecha);//Fecha de creación dela carpeta oarchivoel formato de fecha: dd/mm/yyyy hh:mm
	sprintf(tabla.lista_fecha_modificacion, "%s", fecha);//Fecha de modificación dela carpeta o archivoel formato de fecha: dd/mm/yyyy hh:mm
	sprintf(tabla.disponible, "%d", 1); //si esta libre =0, =1 ocupado
	sprintf(tabla.lista_nombre, "%s", nombre);//Contiene el nombre de la carpeta o archivo
	sprintf(tabla.lista_tipo, "%s", "file");//Para identificar si es una carpeta o archivo
	sprintf(tabla.lista_nombre_padre, "%s", padre);//Indica el nombre de la carpeta padre
	sprintf(tabla.lista_ap_directo_bloque, "%d", fd);//Apuntador al byte o al número de la estructura en donde inicia el bloque de datos que contiene la información del archivo. Null si es carpeta.
	sprintf(tabla.lista_nivel, "%d", nivel);//Número indicando el nivel de jerarquía, hasta un máximo de 4 niveles.
	FATguardar_tabla(ft, tdisco, tabla, activa);
	//actualizando informacion del boot
	f = fopen (directorio, "rb+");
	int posicion=atoi(boot.b_ap_bloque_tabla_indexada)+mbr_address;
	fseek(f,posicion,SEEK_SET);
	//buscando siguiente tabla libre
	sprintf(boot.b_tablas_free, "%d", atoi(boot.b_tablas_free)-1);
	sprintf(boot.b_tablas_count, "%d", atoi(boot.b_tablas_count)+1);
	int ttotal=atoi(boot.b_tablas_free)+atoi(boot.b_tablas_count);
	int k=0;
	int libre=0;
	for(k=0;(k<ttotal) && (libre==0); k++){
		struct struct_tabla ttabla;
		fread(&ttabla, sizeof(ttabla), 1, f);
		if(atoi(ttabla.disponible)==0)
			libre=k+1;
	}
	sprintf(boot.b_next_tabla_free, "%d", libre);
	posicion=atoi(boot.b_ap_bloque_datos)+mbr_address;
	fseek(f, posicion, SEEK_SET);
	ttotal=atoi(boot.b_bloques_free)+atoi(boot.b_bloques_count);
	k=0;
	libre=0;
	for(k=0;(k<ttotal) && (libre==0); k++){
		struct struct_datos tdatos;
		fread(&tdatos, sizeof(tdatos), 1, f);
		if(atoi(tdatos.disponible)==0)
			libre=k+1;
	}
	sprintf(boot.b_next_bloque_free, "%d", libre);
	fseek(f,mbr_address,SEEK_SET);
	fwrite(&boot, sizeof(boot), 1, f);
	fclose(f);
	FATguardar(informacion, tdisco, activa);
}

void EXT3crear_data(char tipo[4], int illave, struct struct_disco tdisco, int nivel, char padre[4], char ubicacion[640]){
	//mostrando creacion de
	printf("\n");
	printf("**********************\n");
	printf("Sistema de archivos EXT3\n");
	if(strcmp(tipo,"dir")==0)
		printf("CREAR DIRECTORIO\n");
	else
		printf("CREAR ARCHIVO\n");
	printf("**********************\n");
	//
	char nombre[50];
	if(strcmp(tipo,"dir")==0){
		printf("Ingrese nombre de la carpeta:\n");
		scanf("%s",nombre);
		
		int repetido=EXT3repetido_carpeta_folder(ubicacion, illave, tdisco, nombre);
		if(repetido==0){
			printf("Guardando...\n");
			char copy2[getsize(nombre)];
			sprintf(copy2,"%s", nombre);
			char *taccion="Carpeta creada: ";
			char accion[getsize(taccion)+getsize(copy2)];
			sprintf(accion,"%s%s", taccion, copy2);
			Bitacora_registro("Crear carpeta", 1, ubicacion, accion, tdisco, 1);
			
			//guardando informacion
			EXT3_crear_carpeta(nombre, tdisco, illave, 1);
			//parte FAT
			while(login==0)
				FATlogin(tdisco, 0);
			FAT_crear_carpeta(nombre, tdisco, nivel, padre, 0);
			
			Bitacora_registro("COPIA:Crear carpeta", 1, ubicacion, accion, tdisco, 0);
			
			//finalizo
			printf("Se creo el directorio exitosamente\n");
		}
	}else if(strcmp(tipo,"file")==0){
		printf("Ingrese nombre del archivo:\n");
		scanf("%s",nombre);
		int repetido=EXT3repetido_carpeta_folder(ubicacion, illave, tdisco, nombre);
		if(repetido==0){
			printf("Ingrese contenido:\n");
			char read[640];
			scanf("%*c%[^\n]",read); 
			char *informacion=read;
			
			char copy2[getsize(nombre)];
			sprintf(copy2,"%s", nombre);
			char copy3[getsize(informacion)];
			sprintf(copy3,"%s", informacion);
			char *taccion="Archivo creado: ";
			char *taccion2=" Contenido: ";
			char accion[getsize(taccion)+getsize(taccion2)+getsize(copy2)+getsize(copy3)];
			sprintf(accion,"%s%s%s%s", taccion, copy2, taccion2, copy3);
			Bitacora_registro("Crear archivo", 0, ubicacion, accion, tdisco, 1);
			
			//guardando bloques de informacion
			char copy[getsize(informacion)];
			sprintf(copy, "%s", informacion);
			EXT3_crear_archivo(nombre, informacion, tdisco, illave, 1);
			//parte FAT
			//parte FAT
			while(login==0)
				FATlogin(tdisco, 0);
				
			Bitacora_registro("COPIA:Crear archivo", 0, ubicacion, accion, tdisco, 0);
			
			FAT_crear_archivo(nombre, copy, tdisco, nivel, padre, 0);
			//finalizo
			printf("Se creo el archivo exitosamente\n");
		}
	}
}

void EXT3eliminar_data(char tipo[4], int illave, struct struct_disco tdisco, int nivel, char padre[4], char ubicacion[640]){
	//mostrando creacion de
	printf("\n");
	printf("**********************\n");
	printf("Sistema de archivos EXT3\n");
	if(strcmp(tipo,"dir")==0)
		printf("ELIMINAR DIRECTORIO\n");
	else
		printf("ELIMINAR ARCHIVO\n");
	printf("**********************\n");
	//
	char nombre[50];
	if(strcmp(tipo,"dir")==0){
		printf("Ingrese nombre de la carpeta a eliminar:\n");
		scanf("%s",nombre);
		printf("Eliminando directorio...\n");
		//eliminando informacion
		EXT3_eliminar_carpeta(nombre, tdisco, illave, 1, ubicacion);
		//parte FAT
		while(login==0)
			FATlogin(tdisco, 0);
		FAT_eliminar_carpeta(nombre, tdisco, nivel, padre, 0, ubicacion);
		//finalizo
	}else if(strcmp(tipo,"file")==0){
		printf("Ingrese nombre del archivo a eliminar:\n");
		scanf("%s",nombre);
		printf("Eliminando archivo...\n");
		//eliminando informacion
		EXT3_eliminar_archivo(nombre, tdisco, illave, 1, ubicacion);
		//parte FAT
		while(login==0)
			FATlogin(tdisco, 0);
		//guardando informacion
		FAT_eliminar_archivo(nombre, tdisco, nivel, padre, 0, ubicacion);
		//finalizo
	}
}

void EXT3renombrar_data(int illave, struct struct_disco tdisco, int nivel, char padre[4], char ubicacion[640]){
	//mostrando creacion de
	printf("\n");
	printf("**********************\n");
	printf("Sistema de archivos EXT3\n");
	printf("RENOMBRAR ARCHIVO\n");
	printf("**********************\n");
	//
	char nombre[50];
	char renombre[50];
	printf("Ingrese nombre del archivo a renombrar:\n");
	scanf("%s",nombre);
	printf("Ingrese nuevo nombre:\n");
	scanf("%s",renombre);
	int repetido=EXT3repetido_carpeta_folder(ubicacion, illave, tdisco, renombre);
	if(repetido==0){
		printf("Renombrando archivo...\n");
		//renombrar informacion
		char ubicacion_copy[640];
		sprintf(ubicacion_copy,"%s%s", ubicacion, nombre);
		EXT3_renombrar_archivo(nombre, renombre, tdisco, illave, 1, ubicacion_copy);
		//parte FAT
		while(login==0)
			FATlogin(tdisco, 0);
		//renombrando informacion
		FAT_renombrar_archivo(nombre, renombre, tdisco, nivel, padre, 0, ubicacion_copy);
		//finalizo
	}
}

void EXT3editar_data(int illave, struct struct_disco tdisco, int nivel, char padre[4], int apuntador, char ubicacion[640]){
	//mostrando creacion de
	printf("\n");
	printf("**********************\n");
	printf("EDITANDO ARCHIVO\n");
	printf("**********************\n");
	//
	printf("Ingrese nuevo contenido:\n");
	char read[640];
	scanf("%*c%[^\n]",read); 
	char *informacion=read;
	char copy[getsize(informacion)];
	sprintf(copy,"%s", informacion);
	//editando archivo
	EXT3editar(informacion, tdisco, illave, 1);
	
	char copy2[getsize(informacion)];
	sprintf(copy2,"%s", informacion);
	char *taccion="nuevo texto: ";
	char accion[getsize(taccion)+getsize(copy2)];
	sprintf(accion,"%s%s", taccion, copy2);
	Bitacora_registro("Editar archivo", 0, ubicacion, accion, tdisco, 1);
	
	//parte FAT
	while(login==0)
		FATlogin(tdisco, 0);
	//editando informacion
	
	Bitacora_registro("COPIA:Editar archivo", 0, ubicacion, accion, tdisco, 0);
		
	FATeditar(copy, tdisco, nivel, padre, 0, apuntador);
	//finalizo
	printf("Archivo editado correctamente\n");
}

void FATcrear_data(char tipo[4], int nivel, char padre[50], struct struct_disco tdisco, int inodo, char ubicacion[640]){
	//mostrando creacion de
	printf("\n");
	printf("**********************\n");
	printf("Sistema de archivos FAT\n");
	if(strcmp(tipo,"dir")==0)
		printf("CREAR DIRECTORIO\n");
	else
		printf("CREAR ARCHIVO\n");
	printf("**********************\n");
	//
	char nombre[50];
	if(strcmp(tipo,"dir")==0){
		printf("Ingrese nombre de la carpeta:\n");
		scanf("%s",nombre);
		int repetido=FATrepetido_carpeta_folder(ubicacion, nivel, -1, padre, tdisco, nombre);
		if(repetido==0){
			printf("Guardando...\n");
			//guardando informacion
			FAT_crear_carpeta(nombre, tdisco, nivel, padre, 1);
			//paret EXT3
			EXT3_crear_carpeta(nombre, tdisco, inodo, 0);
			//finalizo
			
			char copy2[getsize(nombre)];
			sprintf(copy2,"%s", nombre);
			char *taccion="Carpeta creada: ";
			char accion[getsize(taccion)+getsize(copy2)];
			sprintf(accion,"%s%s", taccion, copy2);
			Bitacora_registro("Crear carpeta", 1, ubicacion, accion, tdisco, 1);
			Bitacora_registro("COPIA:Crear carpeta", 1, ubicacion, accion, tdisco, 0);
						
			printf("Se creo el directorio exitosamente\n");
		}
	}else if(strcmp(tipo,"file")==0){
		printf("Ingrese nombre del archivo:\n");
		scanf("%s",nombre);
		int repetido=FATrepetido_carpeta_folder(ubicacion, nivel, -1, padre, tdisco, nombre);
		if(repetido==0){
			printf("Ingrese contenido:\n");
			char read[640];
			scanf("%*c%[^\n]",read); 
			char *informacion=read;
			//guardando informaicion en datos
			FAT_crear_archivo(nombre, informacion, tdisco, nivel, padre, 1);
			//paret EXT3
			EXT3_crear_archivo(nombre, informacion, tdisco, inodo, 0);
			//finalizo
			
			char copy2[getsize(nombre)];
			sprintf(copy2,"%s", nombre);
			char copy3[getsize(informacion)];
			sprintf(copy3,"%s", informacion);
			char *taccion="Archivo creado: ";
			char *taccion2=" Contenido: ";
			char accion[getsize(taccion)+getsize(taccion2)+getsize(copy2)+getsize(copy3)];
			sprintf(accion,"%s%s%s%s", taccion, copy2, taccion2, copy3);
			Bitacora_registro("Crear archivo", 0, ubicacion, accion, tdisco, 1);
			Bitacora_registro("COPIA:Crear archivo", 0, ubicacion, accion, tdisco, 0);
					
			printf("Se creo el archivo exitosamente\n");
		}
	}
}

void FATeliminar_data(char tipo[4], int nivel, char padre[50], struct struct_disco tdisco, int inodo, char ubicacion[640]){
	//mostrando creacion de
	printf("\n");
	printf("**********************\n");
	printf("Sistema de archivos FAT\n");
	if(strcmp(tipo,"dir")==0)
		printf("ELIMINAR DIRECTORIO\n");
	else
		printf("ELIMINAR ARCHIVO\n");
	printf("**********************\n");
	//
	char nombre[50];
	if(strcmp(tipo,"dir")==0){
		printf("Ingrese nombre de la carpeta a eliminar:\n");
		scanf("%s",nombre);
		printf("Eliminando directorio...\n");
		//guardando informacion
		FAT_eliminar_carpeta(nombre, tdisco, nivel, padre, 1, ubicacion);
		//paret EXT3
		EXT3_eliminar_carpeta(nombre, tdisco, inodo, 0, ubicacion);
		//finalizo
	}else if(strcmp(tipo,"file")==0){
		printf("Ingrese nombre del archivo a eliminar:\n");
		scanf("%s",nombre);
		printf("Eliminando archivo...\n");
		//guardando informacion
		FAT_eliminar_archivo(nombre, tdisco, nivel, padre, 1, ubicacion);
		//eliminando informacion
		EXT3_eliminar_archivo(nombre, tdisco, inodo, 0, ubicacion);
		//finalizo
	}
}

void FATeditar_data(int nivel, char padre[50], struct struct_disco tdisco, int inodo, int apuntador, char ubicacion[640]){
	//mostrando creacion de
	printf("\n");
	printf("**********************\n");
	printf("EDITANDO ARCHIVO\n");
	printf("**********************\n");
	//
	printf("Ingrese nuevo contenido:\n");
	char read[640];
	scanf("%*c%[^\n]",read); 
	char *informacion=read;
	char copy[getsize(informacion)];
	sprintf(copy,"%s", informacion);
	char copy2[getsize(informacion)];
	sprintf(copy2,"%s", informacion);
	char *taccion="nuevo texto: ";
	char accion[getsize(taccion)+getsize(copy2)];
	sprintf(accion,"%s%s", taccion, copy2);
	Bitacora_registro("Editar archivo", 0, ubicacion, accion, tdisco, 1);
	Bitacora_registro("COPIA:Editar archivo", 0, ubicacion, accion, tdisco, 0);
	//editando archivo
	FATeditar(informacion, tdisco, nivel, padre, 1, apuntador);
	//editando informacion
	EXT3editar(copy, tdisco, inodo, 0);
	//finalizo
	printf("Archivo editado correctamente\n");
}

void FATrenombrar_data(int nivel, char padre[50], struct struct_disco tdisco, int inodo, char ubicacion[640]){
	//mostrando creacion de
	printf("\n");
	printf("**********************\n");
	printf("Sistema de archivos FAT\n");
	printf("RENOMBRAR ARCHIVO\n");
	printf("**********************\n");
	//
	char nombre[50];
	char renombre[50];
	printf("Ingrese nombre del archivo a renombrar:\n");
	scanf("%s",nombre);
	printf("Ingrese nuevo nombre:\n");
	scanf("%s",renombre);
	int repetido=FATrepetido_carpeta_folder(ubicacion, nivel, -1, padre, tdisco, renombre);
	if(repetido==0){
		printf("Renombrando archivo...\n");
		//guardando informacion
		char ubicacion_copy[640];
		sprintf(ubicacion_copy,"%s%s", ubicacion, nombre);
		FAT_renombrar_archivo(nombre, renombre, tdisco, nivel, padre, 1, ubicacion_copy);
		//renombrar informacion
		EXT3_renombrar_archivo(nombre, renombre, tdisco, inodo, 0, ubicacion_copy);
		//finalizo
	}
}

//listador recursivo EXT3
void EXT3listar_recursivo(char ubicacion[640], int llave, struct struct_disco tdisco){
	//actualizando inodo
	struct struct_inodo inodo=EXT3obtener_inodo(llave, tdisco, 1);
	//printf("Reading:%d:%s\n",llave,inodo.i_tipo);
	if(strcmp(inodo.i_tipo,"dir")==0){
		char *empty="";
		char temporal1[getsize(EXT3loaddata(empty, tdisco, inodo, 1))];
		sprintf(temporal1,"%s",EXT3loaddata(empty, tdisco, inodo, 1));
		char *informacion=temporal1;
		int k=0;
		int contador=1;
		int linea=0;
		int escribiendo=1;
		for(k=0;(k<getsize(informacion)) & ((informacion[k]!=0) || (informacion[k]!=127));k++){
			if(linea==0){
				linea=1;
				printf("%s",ubicacion);
			}
			if(informacion[k]==32){
				escribiendo=0;
			}else if(informacion[k]==10){
				escribiendo=1;
				contador++;
				printf("\n");
				linea=0;
				if((contador-1)>2){
					struct struct_inodo_ubicacion inodo_ubicacion=EXT3get_inodo_from_seleccion(contador-1, inodo, tdisco, 1);
					//muestra de nuevo las opciones
					char seleccion[640];
					if(atoi(inodo_ubicacion.inodo.Llave)!=atoi(inodo.Llave)){
						if(strcmp(inodo_ubicacion.inodo.i_tipo,"dir")==0)
							sprintf(seleccion,"%s%s/", ubicacion, inodo_ubicacion.ubicacion);
						else
							sprintf(seleccion,"%s%s", ubicacion, inodo_ubicacion.ubicacion);
						//entra a la ubicacion
						EXT3listar_recursivo(seleccion, atoi(inodo_ubicacion.inodo.Llave), tdisco);
					}
				}
			}else if(escribiendo==1){
				printf("%c",informacion[k]);
			}
		}
		
	}
}

//listador recursivo FAT
void FATlistar_recursivo(char ubicacion[640], int nivel, int apuntador, char padre[50], struct struct_disco tdisco){
	if(apuntador==-1){
		//folder
		set_disco(tdisco.nombre);
		FILE *f = fopen (directorio, "rb+");
		fseek(f,sizeof(tdisco),SEEK_SET);
		struct struct_mbr mbr;
		fread(&mbr, sizeof(mbr), 1, f);
		fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		int tfree=atoi(boot.b_tablas_free);
		int tcount=atoi(boot.b_tablas_count);
		int ttotal=tfree+tcount;
		//printf("%d-%d-%d\n", tfree, tcount, ttotal);
		int k=0;
		int leidos=0;
		int contador=1;
		//printf("buscando:%d:%s:\n",nivel,padre);
		for(k=0;(k<ttotal) && (leidos<tcount); k++){
			struct struct_tabla tabla;
			fread(&tabla, sizeof(tabla), 1, f);
			if(atoi(tabla.disponible)==1){
				leidos++;
				if((atoi(tabla.lista_nivel)==nivel) && strcmp(tabla.lista_nombre_padre,padre)==0){
					printf("%s%s\n", ubicacion, tabla.lista_nombre);
					struct struct_tabla tabla=FATget_tabla_from_seleccion(contador, nivel, padre, tdisco, 1);
					char seleccion[640];
					if(strcmp(tabla.lista_tipo,"dir")==0)
						sprintf(seleccion,"%s%s/", ubicacion, tabla.lista_nombre);
					else
						sprintf(seleccion,"%s%s", ubicacion, tabla.lista_nombre);
					//entrando
					FATlistar_recursivo(seleccion, nivel+1, atoi(tabla.lista_ap_directo_bloque), tabla.lista_nombre, tdisco);
					contador++;
				}
			}
		}
		fclose(f);
	}
}

//listador recursivo EXT3
int EXT3buscar_carpeta_folder(char ubicacion[640], int llave, struct struct_disco tdisco, char busqueda[50], int buscar_carpeta, int mostrar){
	//actualizando inodo
	struct struct_inodo inodo=EXT3obtener_inodo(llave, tdisco, 1);
	//printf("Reading:%d:%s\n",llave,inodo.i_tipo);
	int escarpeta=1;
	if(strcmp(inodo.i_tipo,"dir")==0){
		if(mostrar==1){
			char *empty="";
			char temporal1[getsize(EXT3loaddata(empty, tdisco, inodo, 1))];
			sprintf(temporal1,"%s",EXT3loaddata(empty, tdisco, inodo, 1));
			char *informacion=temporal1;
			int k=0;
			int contador=1;
			int linea=0;
			int escribiendo=1;
			//busquda
			int bbool=1;
			int bmax=getsize(busqueda);
			int bindex=0;
			//fin
			for(k=0;(k<getsize(informacion)) & ((informacion[k]!=0) || (informacion[k]!=127));k++){
				if(linea==0){
					linea=1;
				}
				if(informacion[k]==32){
					escribiendo=0;
				}else if(informacion[k]==10){
					escribiendo=1;
					contador++;
					//printf("\n");
					struct struct_inodo_ubicacion inodo_ubicacion=EXT3get_inodo_from_seleccion(contador-1, inodo, tdisco, 1);
					char seleccion[640];
					//muestra de nuevo las opciones
					if(atoi(inodo_ubicacion.inodo.Llave)!=atoi(inodo.Llave)){
						if(strcmp(inodo_ubicacion.inodo.i_tipo,"dir")==0)
							sprintf(seleccion,"%s%s/", ubicacion, inodo_ubicacion.ubicacion);
						else
							sprintf(seleccion,"%s%s", ubicacion, inodo_ubicacion.ubicacion);
						//entra a la ubicacion
					}
					if(bbool==1){
						int carpeta=EXT3buscar_carpeta_folder(seleccion, atoi(inodo_ubicacion.inodo.Llave), tdisco, busqueda, buscar_carpeta, 0);
						if(buscar_carpeta==carpeta)
							printf("%s%s\n",ubicacion,busqueda);
						bindex=0;
					}
					bbool=1;
					linea=0;
					if((contador-1)>2){
						EXT3buscar_carpeta_folder(seleccion, atoi(inodo_ubicacion.inodo.Llave), tdisco, busqueda, buscar_carpeta, 1);
					}
				}else if(escribiendo==1){
					//printf("comparacion:%d:%d\n",bindex,bbool);
					if(bindex<bmax){
						if((informacion[k]==busqueda[bindex]) && (bbool==1)){
							bindex++;
						}else{
							bbool=0;
							bindex=0;
						}
					}else
						bbool=0;
					//printf("%c",informacion[k]);
				}
			}
		}
	}else
		escarpeta=0;
	return escarpeta;
}

//listador recursivo EXT3
void EXT3ruta_inodos_bloques(char ubicacion[640], int llave, struct struct_disco tdisco, char busqueda[640]){
	int max=0;
	if(busqueda[0]!=0)
		max=getsize(busqueda);
	int t=0;
	if(busqueda[0]!=0){
		while(t<max && busqueda[t]!=47){
			t++;
		}
	}
	if(busqueda[0]==0)
		t=1;
	char new_word[t];
	int other=max-t-1;
	if(busqueda[0]==0)
		other=1;
	char sig_word[other];
	int u=0;
	//printf("max:%d-other:%d\n",max,t);
	if(busqueda[0]!=0){
		if(max!=t){
			for(u=0;u<max;u++){
				if(u<t){
					new_word[u]=busqueda[u];
				}else if(u==t){
					new_word[u]=0;
				}else{
					sig_word[u-t-1]=busqueda[u];
				}
			}
			sig_word[u-t-1]=0;
		}else{
			sprintf(new_word, "%s", busqueda);
		}
	}
	//------------busqueda new_word
	//actualizando inodo
	struct struct_inodo inodo=EXT3obtener_inodo(llave, tdisco, 1);
	EXT3_inodo_mostrar_informacion(inodo);
	
	//printf("Reading:%d:%s\n",llave,inodo.i_tipo);
	if(strcmp(inodo.i_tipo,"dir")==0){
		char *empty="";
		char temporal1[getsize(EXT3loaddata(empty, tdisco, inodo, 1))];
		sprintf(temporal1,"%s",EXT3loaddata_ruta_bloques(empty, tdisco, inodo, 1));
		if(busqueda[0]!=0){
			char *informacion=temporal1;
			int k=0;
			int contador=1;
			int linea=0;
			int escribiendo=1;
			//busquda
			int bbool=1;
			int bmax=getsize(new_word);
			int bindex=0;
			//fin
			for(k=0;(k<getsize(informacion)) & ((informacion[k]!=0) || (informacion[k]!=127));k++){
				if(linea==0){
					linea=1;
				}
				if(informacion[k]==32){
					escribiendo=0;
				}else if(informacion[k]==10){
					escribiendo=1;
					contador++;
					//printf("\n");
					struct struct_inodo_ubicacion inodo_ubicacion=EXT3get_inodo_from_seleccion(contador-1, inodo, tdisco, 1);
					char seleccion[640];
					//muestra de nuevo las opciones
					if(atoi(inodo_ubicacion.inodo.Llave)!=atoi(inodo.Llave)){
						if(strcmp(inodo_ubicacion.inodo.i_tipo,"dir")==0)
							sprintf(seleccion,"%s%s/", ubicacion, inodo_ubicacion.ubicacion);
						else
							sprintf(seleccion,"%s%s", ubicacion, inodo_ubicacion.ubicacion);
						//entra a la ubicacion
					}
					if(bbool==1){
						printf("::::Encontrado!\n");
						printf("%s%s\n",ubicacion, new_word);
						bindex=0;
						if((contador-1)>2){
							if(max!=t)
								EXT3ruta_inodos_bloques(seleccion, atoi(inodo_ubicacion.inodo.Llave), tdisco, sig_word);
							else if(max==t){
								sig_word[0]=0;
								EXT3ruta_inodos_bloques(seleccion, atoi(inodo_ubicacion.inodo.Llave), tdisco, sig_word);
							}
						}
					}
					bbool=1;
					linea=0;
				}else if(escribiendo==1){
					//printf("comparacion:%d:%d\n",bindex,bbool);
					if(bindex<bmax){
						if((informacion[k]==new_word[bindex]) && (bbool==1)){
							bindex++;
						}else{
							bbool=0;
							bindex=0;
						}
					}else
						bbool=0;
					//printf("%c",informacion[k]);
				}
			}
		}
	}else{
		char *empty="";
		empty=EXT3loaddata_ruta_bloques(empty, tdisco, inodo, 1);
	}
}

//listador recursivo FAT
void FATbuscar_carpeta_folder(char ubicacion[640], int nivel, int apuntador, char padre[50], struct struct_disco tdisco, char busqueda[50], int buscar_carpeta){
	if(apuntador==-1){
		//folder
		set_disco(tdisco.nombre);
		FILE *f = fopen (directorio, "rb+");
		fseek(f,sizeof(tdisco),SEEK_SET);
		struct struct_mbr mbr;
		fread(&mbr, sizeof(mbr), 1, f);
		fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		int tfree=atoi(boot.b_tablas_free);
		int tcount=atoi(boot.b_tablas_count);
		int ttotal=tfree+tcount;
		//printf("%d-%d-%d\n", tfree, tcount, ttotal);
		int k=0;
		int leidos=0;
		int contador=1;
		//printf("buscando:%d:%s:\n",nivel,padre);
		for(k=0;(k<ttotal) && (leidos<tcount); k++){
			struct struct_tabla tabla;
			fread(&tabla, sizeof(tabla), 1, f);
			if(atoi(tabla.disponible)==1){
				leidos++;
				if((atoi(tabla.lista_nivel)==nivel) && strcmp(tabla.lista_nombre_padre,padre)==0){
					struct struct_tabla tabla=FATget_tabla_from_seleccion(contador, nivel, padre, tdisco, 1);
					int new_apuntador=atoi(tabla.lista_ap_directo_bloque);
					char seleccion[640];
					if(strcmp(tabla.lista_tipo,"dir")==0)
						sprintf(seleccion,"%s%s/", ubicacion, tabla.lista_nombre);
					else
						sprintf(seleccion,"%s%s", ubicacion, tabla.lista_nombre);
					if(strcmp(tabla.lista_nombre,busqueda)==0){
						if(new_apuntador==-1 && buscar_carpeta==1){
							//carpeta
							printf("%s%s\n", ubicacion, tabla.lista_nombre);
						}else if(new_apuntador!=-1 && buscar_carpeta==0){
							//archivo
							printf("%s%s\n", ubicacion, tabla.lista_nombre);
						}
					}
					//entrando
					FATbuscar_carpeta_folder(seleccion, nivel+1, new_apuntador, tabla.lista_nombre, tdisco, busqueda, buscar_carpeta);
					contador++;
				}
			}
		}
		fclose(f);
	}
}

//navegador EXT3
void EXT3navegador(char ubicacion[640], int llave, struct struct_disco tdisco, int nivel, int apuntador, char padre[4]){
	//actualizando inodo
	struct struct_inodo inodo=EXT3obtener_inodo_set_access(llave, tdisco, 1);
	printf("\nSistema de archivos EXT3\n");
	printf("%s\n",ubicacion);
	//printf("Reading:%d:%s\n",llave,inodo.i_tipo);
	if(strcmp(inodo.i_tipo,"dir")==0){
		printf("Opciones:\n");
		char *empty="";
		//--
		//printf("\nEXT3navegador3.informacion:%s\n",print(EXT3loaddata(empty, tdisco, inodo)));
		//printf("EXT3navegador3.informacion:%s\n",print(EXT3loaddata(empty, tdisco, inodo)));
		//--
		char temporal1[getsize(EXT3loaddata(empty, tdisco, inodo, 1))];
		sprintf(temporal1,"%s",EXT3loaddata(empty, tdisco, inodo, 1));
		char *informacion=temporal1;
		//--
		//printf("EXT3navegador3.informacion:%s\n",print(temporal1));
		//printf("EXT3navegador3.informacion:%s\n",print(informacion));
		//--
		int k=0;
		int contador=1;
		int linea=0;
		int escribiendo=1;
		//--
		//printf("EXT3navegador3.informacion:");
		//for(k=0;(k<getsize(informacion)) & ((informacion[k]!=0) || (informacion[k]!=127));k++){
		//	printf(":%d:",informacion[k]);
		//}
		//printf("\n");
		//--
		//--
		//printf("EXT3navegador4.contador:%d\n",contador);
		//printf("EXT3navegador4.linea:%d\n",linea);
		//printf("EXT3navegador4.escribiendo:%d\n\n",escribiendo);
		//--
		for(k=0;(k<getsize(informacion)) & ((informacion[k]!=0) || (informacion[k]!=127));k++){
			if(linea==0){
				printf("%d. ",contador);
				linea=1;
			}
			if(informacion[k]==32){
				escribiendo=0;
			}else if(informacion[k]==10){
				escribiendo=1;
				contador++;
				printf("\n");
				linea=0;
			}else if(escribiendo==1){
				printf("%c",informacion[k]);
			}
			//--
			//printf("EXT3navegador4.contador:%d\n",contador);
			//printf("EXT3navegador4.linea:%d\n",linea);
			//printf("EXT3navegador4.escribiendo:%d\n\n",escribiendo);
			//--
		}
		int max=contador;
		printf("\nDirectorios\n");
		printf("%d. Crear directorio\n", contador); contador++;
		printf("%d. Eliminar directorio\n", contador); contador++;
		printf("%d. Listar directorio recursivo\n", contador); contador++;
		printf("%d. Buscar directorio\n", contador); contador++;
		printf("\nArchivos\n");
		printf("%d. Crear y guardar archivo\n", contador); contador++;
		printf("%d. Eliminar archivo\n", contador); contador++;
		printf("%d. Renombrar archivo\n", contador); contador++;
		printf("%d. Buscar archivo\n", contador); contador++;
		printf("\nFunciones especiales\n");
		printf("%d. Rutas inodos y bloques de archivos y carpetas\n", contador); contador++;
		printf("%d. Mostrar bloque segun id\n", contador); contador++;
		printf("\nMas\n");
		printf("%d. Regresar \n", contador);
		//analizando opciones
		int menu=0;
		while((menu==0) && ((menu<1) || (menu>contador))){
			if (scanf("%d", (&menu)) == 0){
				while (getchar() != '\n'){
					printf("%s","Error, ingrese numero: \n");
					scanf("%d", (&menu));
				}
			}
			if((menu<1) || (menu>contador)){
				printf("Seleccione una opcion valida\n");
			}
		}
		if((menu==1) || (menu==2)){
			printf("¡Alerta RAID!\nDireccion no compatible con sistema FAT\n");
			//de nuevo
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((menu>2) && (menu<max)){
			struct struct_inodo_ubicacion inodo_ubicacion=EXT3get_inodo_from_seleccion(menu, inodo, tdisco, 1);
			char seleccion[640];
			if(atoi(inodo_ubicacion.inodo.Llave)!=atoi(inodo.Llave)){
				if(strcmp(inodo_ubicacion.inodo.i_tipo,"dir")==0)
					sprintf(seleccion,"%s%s/", ubicacion, inodo_ubicacion.ubicacion);
				else
					sprintf(seleccion,"%s%s", ubicacion, inodo_ubicacion.ubicacion);
				//parte FAT
				struct struct_tabla tabla=FATget_tabla_from_seleccion(menu-2, nivel, padre, tdisco, 0);
				//entra a la ubicacion
				EXT3navegador(seleccion, atoi(inodo_ubicacion.inodo.Llave), tdisco, nivel+1, atoi(tabla.lista_ap_directo_bloque), tabla.lista_nombre);
			}
			//muestra de nuevo las opciones
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if(max==menu){
			//crear data
			EXT3crear_data("dir", atoi(inodo.Llave), tdisco, nivel, padre, ubicacion);
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+1)==menu){
			//eliminar data
			EXT3eliminar_data("dir", atoi(inodo.Llave), tdisco, nivel, padre, ubicacion);
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+2)==menu){
			//listar directorio recursivo
			printf("\n::::::Directorio recursivo::::::\n\n");
			EXT3listar_recursivo(ubicacion, llave, tdisco);
			printf("\n\n::::::::::::\n");
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+3)==menu){
			//listar directorio recursivo
			printf("\n::::::Buscar directorio::::::\n\n");
			char busqueda[50];
			printf("Ingrese nombre de la carpeta a buscar:\n");
			scanf("%s",busqueda);
			printf("Buscando...\n::::::::::\n\n");
			EXT3buscar_carpeta_folder(ubicacion, llave, tdisco,busqueda, 1, 1);
			printf("\n::::::::::\n...finalizado\n");
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+4)==menu){
			//crear data
			EXT3crear_data("file", atoi(inodo.Llave), tdisco, nivel, padre, ubicacion);
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+5)==menu){
			//crear data
			EXT3eliminar_data("file", atoi(inodo.Llave), tdisco, nivel, padre, ubicacion);
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+6)==menu){
			//crear data
			EXT3renombrar_data(atoi(inodo.Llave), tdisco, nivel, padre, ubicacion);
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+7)==menu){
			//listar directorio recursivo
			printf("\n::::::Buscar archivo::::::\n\n");
			char busqueda[50];
			printf("Ingrese nombre del archivo a buscar:\n");
			scanf("%s",busqueda);
			printf("Buscando...\n::::::::::\n\n");
			EXT3buscar_carpeta_folder(ubicacion, llave, tdisco,busqueda, 0, 1);
			printf("\n::::::::::\n...finalizado\n");
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+8)==menu){
			//listar directorio recursivo
			printf("\n::::::Rutas inodos bloques::::::\n\n");
			char busqueda[640];
			printf("Ingrese ruta:\n");
			scanf("%s",busqueda);
			printf("Analizando...\n::::::::::\n\n");
			EXT3ruta_inodos_bloques(ubicacion, llave, tdisco, busqueda);
			printf("\n::::::::::\n...finalizado\n");
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}else if((max+9)==menu){
			//listar directorio recursivo
			printf("\n::::::Mostrar bloque segun id::::::\n\n");
			printf("Ingrese id del bloque:\n");
			
			int busqueda=0;
			while(busqueda==0){
				if (scanf("%d", (&busqueda)) == 0){
					while (getchar() != '\n'){
						printf("%s","Error, ingrese numero: \n");
						scanf("%d", (&busqueda));
					}
				}
				if(busqueda<=0){
					printf("Ingrese un numero valido\n");
					busqueda=0;
				}
			}
			
			printf("Analizando...\n::::::::::\n\n");
			struct struct_bloque bloque_info=EXT3obtener_bloque(busqueda, tdisco, 1);
			EXT3_bloque_mostrar_informacion(bloque_info, busqueda);
			printf("\n::::::::::\n...finalizado\n");
			//regresar
			EXT3navegador(ubicacion, llave, tdisco, nivel, apuntador, padre);
		}
	}else{
		printf("Contenido:\n----------\n\n");
		char *empty="";
		//--
		//printf("\nEXT3navegador3.informacion:%s\n",print(EXT3loaddata(empty, tdisco, inodo)));
		//printf("EXT3navegador3.informacion:%s\n",print(EXT3loaddata(empty, tdisco, inodo)));
		//--
		char *tempo=EXT3loaddata(empty, tdisco, inodo, 1);
		char temporal1[getsize(tempo)];
		sprintf(temporal1,"%s",tempo);
		char *informacion=temporal1;
		//--
		//printf("EXT3navegador3.informacion:%s\n",print(temporal1));
		//printf("EXT3navegador3.informacion:%s\n",print(informacion));
		//--
		int contador=1;
		//--
		//printf("EXT3navegador3.informacion:");
		//for(k=0;(k<getsize(informacion)) & ((informacion[k]!=0) || (informacion[k]!=127));k++){
		//	printf(":%d:",informacion[k]);
		//}
		//printf("\n");
		//--
		//--
		//printf("EXT3navegador4.contador:%d\n",contador);
		//printf("EXT3navegador4.linea:%d\n",linea);
		//printf("EXT3navegador4.escribiendo:%d\n\n",escribiendo);
		//--
		printf("%s\n\n----------\n",informacion);
		int max=contador;
		printf("\nArchivos\n");
		printf("%d. Editar \n", contador);contador++;
		printf("\nMas\n");
		printf("%d. Regresar \n", contador);
		//analizando opciones
		int menu=0;
		while((menu==0) && ((menu<1) || (menu>contador))){
			if (scanf("%d", (&menu)) == 0){
				while (getchar() != '\n'){
					printf("%s","Error, ingrese numero: \n");
					scanf("%d", (&menu));
				}
			}
			if((menu<1) || (menu>contador)){
				printf("Seleccione una opcion valida\n");
			}
		}
		if(max==menu){
			//editar
			EXT3editar_data(atoi(inodo.Llave), tdisco, nivel, padre, apuntador, ubicacion);
		}else if((max+1)==menu){
			//regresar
			printf("Regresando...\n");
		}
	}
}

//navegador FAT: ubicacion, nivel=nivel de gerarquia, apuntador=apuntador al bloque, -1 igual null que es carpeta, disco
void FATnavegador(char ubicacion[640], int nivel, int apuntador, char padre[50], struct struct_disco tdisco, int inodo){
	//printf(":::illave:%d:nivel:%d:apuntado:%d:padre:%s:\n", inodo, nivel, apuntador, padre);
	printf("\nSistema de archivos FAT\n");
	printf("%s\n",ubicacion);
	if(apuntador==-1){
		//folder
		printf("Opciones:\n");
		set_disco(tdisco.nombre);
		FILE *f = fopen (directorio, "rb+");
		fseek(f,sizeof(tdisco),SEEK_SET);
		struct struct_mbr mbr;
		fread(&mbr, sizeof(mbr), 1, f);
		fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		int tfree=atoi(boot.b_tablas_free);
		int tcount=atoi(boot.b_tablas_count);
		int ttotal=tfree+tcount;
		//printf("%d-%d-%d\n", tfree, tcount, ttotal);
		int k=0;
		int leidos=0;
		int contador=1;
		//printf("buscando:%d:%s:\n",nivel,padre);
		for(k=0;(k<ttotal) && (leidos<tcount); k++){
		//for(k=0;(k<10); k++){
			struct struct_tabla tabla;
			fread(&tabla, sizeof(tabla), 1, f);
			//printf("leyendo:%s:%s:%s:\n",tabla.lista_nombre,tabla.lista_nivel,tabla.lista_nombre_padre);
			//printf("tabla %d disponible:%d\n",k, atoi(tabla.disponible));
			//printf("tabla nivel:%d\n", atoi(tabla.lista_nivel));
			if(atoi(tabla.disponible)==1){
				leidos++;
				if((atoi(tabla.lista_nivel)==nivel) && strcmp(tabla.lista_nombre_padre,padre)==0){
					printf("%d. %s\n", contador, tabla.lista_nombre);
					contador++;
				}
			}
		}
		fclose(f);
		int max=contador;
		printf("\nDirectorios\n");
		printf("%d. Crear directorio\n", contador); contador++;
		printf("%d. Eliminar directorio\n", contador); contador++;
		printf("%d. Listar directorio recursivo\n", contador); contador++;
		printf("%d. Buscar directorio\n", contador); contador++;
		printf("\nArchivos\n");
		printf("%d. Crear y guardar archivo\n", contador); contador++;
		printf("%d. Eliminar archivo\n", contador); contador++;
		printf("%d. Renombrar archivo\n", contador); contador++;
		printf("%d. Buscar archivo\n", contador); contador++;
		printf("\nMas\n");
		printf("%d. Regresar \n", contador);
		//analizando opciones
		int menu=0;
		while((menu==0) && ((menu<1) || (menu>contador))){
			if (scanf("%d", (&menu)) == 0){
				while (getchar() != '\n'){
					printf("%s","Error, ingrese numero: \n");
					scanf("%d", (&menu));
				}
			}
			if((menu<1) || (menu>contador)){
				printf("Seleccione una opcion valida\n");
			}
		}
		if((menu>0) && (menu<max)){
			//entrando a la direccion
			struct struct_tabla tabla=FATget_tabla_from_seleccion(menu, nivel, padre, tdisco, 1);
			struct struct_inodo_ubicacion inodo_ubicacion=EXT3get_inodo_from_seleccion(menu+2, EXT3obtener_inodo(inodo, tdisco, 0), tdisco, 0);
			char seleccion[640];
			if(strcmp(tabla.lista_tipo,"dir")==0)
				sprintf(seleccion,"%s%s/", ubicacion, tabla.lista_nombre);
			else
				sprintf(seleccion,"%s%s", ubicacion, tabla.lista_nombre);
			//entrando
			FATnavegador(seleccion, nivel+1, atoi(tabla.lista_ap_directo_bloque), tabla.lista_nombre, tdisco, atoi(inodo_ubicacion.inodo.Llave));
			//regresando
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}else if(max==menu){
			//crear data
			FATcrear_data("dir", nivel, padre, tdisco, inodo, ubicacion);
			//regresando
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}else if((max+1)==menu){
			//crear data
			FATeliminar_data("dir", nivel, padre, tdisco, inodo, ubicacion);
			//regresar
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}else if((max+2)==menu){
			//listar directorio recursivo
			printf("\n::::::Directorio recursivo::::::\n\n");
			FATlistar_recursivo(ubicacion, nivel, apuntador, padre, tdisco);
			printf("\n\n::::::::::::\n");
			//regresar
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}else if((max+3)==menu){
			//listar directorio recursivo
			printf("\n::::::Buscar directorio::::::\n\n");
			char busqueda[50];
			printf("Ingrese nombre de la carpeta a buscar:\n");
			scanf("%s",busqueda);
			printf("Buscando...\n::::::::::\n\n");
			FATbuscar_carpeta_folder(ubicacion, nivel, apuntador, padre, tdisco, busqueda, 1);
			printf("\n::::::::::\n...finalizado\n");
			//regresar
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}else if((max+4)==menu){
			//crear data
			FATcrear_data("file", nivel, padre, tdisco, inodo, ubicacion);
			//regresar
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}else if((max+5)==menu){
			//crear data
			FATeliminar_data("file", nivel, padre, tdisco, inodo, ubicacion);
			//regresar
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}else if((max+6)==menu){
			//crear data
			FATrenombrar_data(nivel, padre, tdisco, inodo, ubicacion);
			//regresar
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}else if((max+7)==menu){
			//listar directorio recursivo
			printf("\n::::::Buscar archivo::::::\n\n");
			char busqueda[50];
			printf("Ingrese nombre del archivo a buscar:\n");
			scanf("%s",busqueda);
			printf("Buscando...\n::::::::::\n\n");
			FATbuscar_carpeta_folder(ubicacion, nivel, apuntador, padre, tdisco, busqueda, 0);
			printf("\n::::::::::\n...finalizado\n");
			//regresar
			FATnavegador(ubicacion, nivel, apuntador, padre, tdisco, inodo);
		}
	}else{
		//archivo
		printf("Contenido:\n----------\n\n");
		char *obtenido=FATloaddata(apuntador, tdisco, 1);
		char temporal1[getsize(obtenido)];
		sprintf(temporal1,"%s",obtenido);
		char *informacion=temporal1;
		int contador=1;
		printf("%s\n\n----------\n",informacion);
		int max=contador;
		printf("\nArchivos\n");
		printf("%d. Editar \n", contador);contador++;
		printf("\nMas\n");
		printf("%d. Regresar \n", contador);
		//analizando opciones
		int menu=0;
		while((menu==0) && ((menu<1) || (menu>contador))){
			if (scanf("%d", (&menu)) == 0){
				while (getchar() != '\n'){
					printf("%s","Error, ingrese numero: \n");
					scanf("%d", (&menu));
				}
			}
			if((menu<1) || (menu>contador)){
				printf("Seleccione una opcion valida\n");
			}
		}
		if(max==menu){
			//editar
			FATeditar_data(nivel, padre, tdisco, inodo, apuntador, ubicacion);
		}if((max+1)==menu){
			//regresar
			printf("Regresando...\n");
		}
	}
	
}

//montar particion
void montar_particion(struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
	//printf("Sistema de archivos:%s\n",mbr.mbr_tipo_sistema_archivos);
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		//actualizando informacion de montaje
		struct struct_superbloque superbloque;
		fread(&superbloque, sizeof(superbloque), 1, f);
		settime();
		sprintf(superbloque.sb_mount_time, "%s", fecha);
		sprintf(superbloque.sb_mount_count, "%d", atoi(superbloque.sb_mount_count)+1);
		rewind(f);
		fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
		fwrite(&superbloque, sizeof(superbloque), 1, f);
		//leyendo inodo root
		fseek(f,atoi(mbr.mbr_byte_particion)+atoi(superbloque.sb_first_inodo),SEEK_SET);
		struct struct_inodo inodo;
		fread(&inodo, sizeof(inodo), 1, f);
		//navegador
		char ubicacion[640];
		sprintf(ubicacion, "%s%s",tdisco.nombre,"://");
		fclose(f);
		//entrando al sistema de archivos
		char padre[50];
		sprintf(padre, "%s", "");
		//printf("inodo raiz:%s\n", inodo.Llave);
		EXT3navegador(ubicacion, atoi(inodo.Llave), tdisco, 1, -1, padre);
		//actualizando informacion de des-montaje
		f = fopen (directorio, "rb+");
		fseek(f,sizeof(tdisco),SEEK_SET);
		fread(&mbr, sizeof(mbr), 1, f);
		fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
		fread(&superbloque, sizeof(superbloque), 1, f);
		sprintf(superbloque.sb_write_time, "%s", superbloque.sb_mount_time);
		fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
		fwrite(&superbloque, sizeof(superbloque), 1, f);
		fclose(f);
		//saliendo del login FAT
		login=0;
	}else if(strcmp(mbr.mbr_tipo_sistema_archivos,"FAT")==0){
		//iniciando sesion
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		FATlogin(tdisco, 1);
		if(login==1){
			//actualizando informacion del boot
			sprintf(boot.b_montajes_count, "%d", atoi(boot.b_montajes_count)+1);
			fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
			fwrite(&boot, sizeof(boot), 1, f);
			fclose(f);
			//entrando al sistema de archivos
			//navegador
			char ubicacion[640];
			sprintf(ubicacion, "%s%s",boot.b_nombre_unidad,"://");
			char padre[50];
			sprintf(padre, "%s", "");
			//obteniendo INODO raiz de EXT3
			//--------------
			//actualizando informacion de montaje
			struct struct_superbloque superbloque;
			f = fopen (directorio, "rb+");
			fseek(f,atoi(mbr.mbr_byte_particion_desactivada),SEEK_SET);
			fread(&superbloque, sizeof(superbloque), 1, f);
			//leyendo inodo root
			fseek(f,atoi(mbr.mbr_byte_particion_desactivada)+atoi(superbloque.sb_first_inodo),SEEK_SET);
			struct struct_inodo inodo;
			fread(&inodo, sizeof(inodo), 1, f);
			fclose(f);
			//printf("inodo raiz:%s\n", inodo.Llave);
			//--------------
			FATnavegador(ubicacion, 1, -1, padre, tdisco, atoi(inodo.Llave));
			//actualizando informacion de des-montaje
			f = fopen (directorio, "rb+");
			fseek(f,sizeof(tdisco),SEEK_SET);
			fread(&mbr, sizeof(mbr), 1, f);
			fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
			fread(&boot, sizeof(boot), 1, f);
			settime();
			sprintf(boot.b_date_ultimo_montaje, "%s", fecha);
			fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
			fwrite(&boot, sizeof(boot), 1, f);
			fclose(f);
		}
		login=0;
		//entrando al sistema de archivos
	}
	//cerrando archivo
}

//area de reportes

void EXT3_reporte_inodos(struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	set_disco_reporte(tdisco,"inodos");
	printf("Reporte creado en:\n-------------\n");
	printf("%s\n-------------\n", directorio_reporte);
	printf("Presione una tecla para continuar...\n");
	FILE *freporte=freopen(directorio_reporte, "w" ,stdout);
	printf("Reporte de inodos:\n\n");
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//
	int max=atoi(superbloque.sb_numero_log);
	char mapa[max];
	fread(&mapa, sizeof(mapa), 1, f);
	fclose(f);
	int t=0;
	int lines=0;
	for(t=0;t<max; t++){
		printf("%d", mapa[t]);
		if(lines==50){
			printf("\n");
			lines=-1;
		}else if(t!=(max-1))
			printf(",");
		lines++;
	}
	printf("\n");
	fclose(freporte);
	freopen("/dev/tty","w",stdout); 
	//salida
	char c;
	scanf("%c",&c);
	getchar();
}

void EXT3_reporte_bloques(struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	set_disco_reporte(tdisco,"bloques");
	printf("Reporte creado en:\n-------------\n");
	printf("%s\n-------------\n", directorio_reporte);
	printf("Presione una tecla para continuar...\n");
	FILE *freporte=freopen(directorio_reporte, "w" ,stdout);
	printf("Reporte de bloques:\n\n");
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_superbloque superbloque;
	fread(&superbloque, sizeof(superbloque), 1, f);
	//
	int max=atoi(superbloque.sb_numero_log);
	char mapa[max];
	char tmapa[max];
	fread(&tmapa, sizeof(tmapa), 1, f);
	fread(&mapa, sizeof(mapa), 1, f);
	fclose(f);
	int t=0;
	int lines=0;
	for(t=0;t<max; t++){
		printf("%d", mapa[t]);
		if(lines==50){
			printf("\n");
			lines=-1;
		}else if(t!=(max-1))
			printf(",");
		lines++;
	}
	printf("\n");
	fclose(freporte);
	freopen("/dev/tty","w",stdout); 
	//salida
	char c;
	scanf("%c",&c);
	getchar();
}

void FAT_reporte_datos(struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	set_disco_reporte(tdisco,"bloques");
	printf("Reporte creado en:\n-------------\n");
	printf("%s\n-------------\n", directorio_reporte);
	printf("Presione una tecla para continuar...\n");
	FILE *freporte=freopen(directorio_reporte, "w" ,stdout);
	printf("Reporte de bloques de datos:\n\n");
	//leyendo estructuras
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int mbr_address=atoi(mbr.mbr_byte_particion);
	fseek(f, mbr_address,SEEK_SET);
	struct struct_boot boot;
	fread(&boot, sizeof(boot), 1, f);
	struct struct_datos datos;
	fseek(f, mbr_address + atoi(boot.b_ap_bloque_datos),SEEK_SET);
	//
	int max=atoi(boot.b_log_count)+atoi(boot.b_log_free);
	int t=0;
	int lines=0;
	for(t=0;t<max; t++){
		fread(&datos, sizeof(datos), 1, f);
		printf("%c", datos.disponible[0]);
		if(lines==50){
			printf("\n");
			lines=-1;
		}else if(t!=(max-1))
			printf(",");
		lines++;
	}
	printf("\n");
	fclose(f);
	fclose(freporte);
    freopen("/dev/tty","w",stdout);  
	//salida
	char c;
	scanf("%c",&c);
	getchar();
}

//reporte inodos
void reportes(struct struct_disco tdisco){
	inicializacion_reporte();
	printf("\n");
	printf("**********************\n");
	printf("REPORTES\n");
	printf("**********************\n");
	
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	fseek(f,atoi(mbr.mbr_byte_particion),SEEK_SET);
	//printf("Sistema de archivos:%s\n",mbr.mbr_tipo_sistema_archivos);
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		int contador=1;
		printf("%d. Reporte del Bitmap de tabla de i-nodos\n", contador); contador++;
		printf("%d. Reporte del Bitmap de bloque de datos\n", contador); contador++;
		printf("%d. Reporte de Bitácora.\n", contador); contador++;
		printf("\nMas\n");
		printf("%d. Regresar \n", contador);
		//analizando opciones
		int menu=0;
		while((menu==0) && ((menu<1) || (menu>contador))){
			if (scanf("%d", (&menu)) == 0){
				while (getchar() != '\n'){
					printf("%s","Error, ingrese numero: \n");
					scanf("%d", (&menu));
				}
			}
			if((menu<1) || (menu>contador)){
				printf("Seleccione una opcion valida\n");
			}
		}
		if(menu==1){
			EXT3_reporte_inodos(tdisco);
			reportes(tdisco);
		}else if(menu==2){
			EXT3_reporte_bloques(tdisco);
			reportes(tdisco);
		}else if(menu==3){
			Bitacora_reporte(tdisco);
			reportes(tdisco);
		}
	}else if(strcmp(mbr.mbr_tipo_sistema_archivos,"FAT")==0){
		//iniciando sesion
		if(login==0)
			FATlogin(tdisco, 1);
		if(login==1){
			int contador=1;
			printf("%d. Reporte de Bloques de datos\n", contador); contador++;
			printf("%d. Reporte de Bitácora.\n", contador); contador++;
			printf("\nMas\n");
			printf("%d. Regresar \n", contador);
			//analizando opciones
			int menu=0;
			while((menu==0) && ((menu<1) || (menu>contador))){
				if (scanf("%d", (&menu)) == 0){
					while (getchar() != '\n'){
						printf("%s","Error, ingrese numero: \n");
						scanf("%d", (&menu));
					}
				}
				if((menu<1) || (menu>contador)){
					printf("Seleccione una opcion valida\n");
				}
			}	
			if(menu==1){
				FAT_reporte_datos(tdisco);
				reportes(tdisco);
			}else if(menu==2){
				Bitacora_reporte(tdisco);
				reportes(tdisco);
			}
		}
		login=0;
		//entrando al sistema de archivos
	}
	//cerrando archivo
}

//creando particiones
int ext(int size, int posicion, struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,posicion,SEEK_SET);
	//creando estructuras
	struct struct_superbloque superbloque;
	struct struct_inodo inodo;
	struct struct_bloque bloque;
	struct struct_log log;
	//calculando informacion...........
	int m=(int)((size-sizeof(superbloque))/(2+sizeof(inodo)+sizeof(bloque)+sizeof(log)));
	int rtn=sizeof(superbloque) + sizeof(inodo)*m + sizeof(bloque)*m + sizeof(log)*m + 2*m;
	//generando informacion
	//superbloque:
	settime();
	sprintf(superbloque.sb_date_creacion, "%s", fecha);
	sprintf(superbloque.sb_mount_time, "%s", "00/00/0000 00:00");
	sprintf(superbloque.sb_write_time, "%s", "00/00/0000 00:00");
	sprintf(superbloque.sb_numero_inodos, "%d", m);
	sprintf(superbloque.sb_numero_bloques, "%d", m);
	sprintf(superbloque.sb_numero_log, "%d", m);
	sprintf(superbloque.sb_tamanio_bloque, "%d", (int)sizeof(bloque));
	sprintf(superbloque.sb_numero_magico, "%d", 72826);
	sprintf(superbloque.sb_bloques_freee, "%d", m-1);
	sprintf(superbloque.sb_inodos_free, "%d", m-1);
	sprintf(superbloque.sb_log_free, "%d", m);
	sprintf(superbloque.sb_mount_count,"%d", 0);
	sprintf(superbloque.sb_ap_bitacora, "%d", (int)(sizeof(superbloque)+2*m+m*sizeof(inodo)+m*sizeof(bloque)));
	sprintf(superbloque.sb_first_inodo, "%d", (int)(sizeof(superbloque)+2*m));
	sprintf(superbloque.sb_first_bloque, "%d", (int)(sizeof(superbloque)+2*m+m*sizeof(inodo)));
	sprintf(superbloque.sb_fist_free_bitmapinodo,"%d", 2);
	sprintf(superbloque.sb_first_free_bitmapbloque,"%d", 2);
	sprintf(superbloque.sb_first_free_log,"%d", 0);
	//escribiendo bloque
	fwrite(&superbloque, (int)sizeof(superbloque), 1, f);
	//escribiendo bitmaps
	//mapa
	char mapa[m];
	mapa[0]=1;
	for(ifor=1;ifor<m;ifor++)
		mapa[ifor]=0;
	fwrite(&mapa, (int)sizeof(mapa), 1, f);
	char mapa2[m];
	mapa2[0]=1;
	for(ifor=1;ifor<m;ifor++)
		mapa2[ifor]=0;
	fwrite(&mapa2, (int)sizeof(mapa2), 1, f);
	//informacion a guardar
	char *informacion=". 1\n";
	//escribiendo inodos
	//inodo inicial
	struct struct_inodo tinodo;
	settime();
	sprintf(tinodo.i_date_mod,"%s", fecha);
	sprintf(tinodo.i_time_last_access, "%s", "00/00/0000 00:00");
	sprintf(tinodo.i_ctime, "%s", fecha);
	sprintf(tinodo.Llave,"%d", 1);
	sprintf(tinodo.i_tipo,"%s", "dir");
	sprintf(tinodo.i_tam_archivo,"%d", getsize(informacion));
	sprintf(tinodo.i_asig_bloques,"%d", 1);
	sprintf(tinodo.i_block1,"%d", 1);
	sprintf(tinodo.i_block2,"%d", 0);
	sprintf(tinodo.i_block3,"%d", 0);
	sprintf(tinodo.i_block4,"%d", 0);
	sprintf(tinodo.i_Iblock,"%d", 0);
	fwrite(&tinodo, sizeof(tinodo), 1, f);
	//demas inodos
	settime();
	sprintf(inodo.i_date_mod,"%s", fecha);
	sprintf(inodo.i_ctime, "%s", fecha);
	sprintf(inodo.i_time_last_access, "%s", "00/00/0000 00:00");
	sprintf(inodo.i_tam_archivo,"%d", 0);
	sprintf(inodo.i_asig_bloques,"%d", 0);
	sprintf(inodo.i_block1,"%d", 0);
	sprintf(inodo.i_block2,"%d", 0);
	sprintf(inodo.i_block3,"%d", 0);
	sprintf(inodo.i_block4,"%d", 0);
	sprintf(inodo.i_Iblock,"%d", 0);
	for(ifor=1;ifor<m;ifor++){
		sprintf(inodo.Llave,"%d", ifor+1);
		fwrite(&inodo, sizeof(inodo), 1, f);
	}
	//escribiendo bloques
	//bloque raiz
	struct struct_bloque tbloque;
	sprintf(tbloque.estado,"%s","1");
	sprintf(tbloque.data,"%s",". 1\n.. 1\n");
	fwrite(&tbloque, sizeof(tbloque), 1, f);
	//bloques vacios
	sprintf(bloque.estado,"%d", 0);
	for(ifor=1;ifor<m;ifor++){
		fwrite(&bloque, sizeof(bloque), 1, f);
	}
	//escribiendo logs
	for(ifor=0;ifor<m;ifor++)
		fwrite(&log, sizeof(log), 1, f);
	//actualizando numero de particiones
	rewind(f);
	fread(&tdisco, sizeof(tdisco), 1, f);
	sprintf(tdisco.particiones, "%d", atoi(tdisco.particiones)+1);
	rewind(f);
	fwrite(&tdisco, sizeof(tdisco), 1, f);
	//cerrando archivo
	fclose(f);
	printf("Particion ext3 creada exitosamente!\n");
	return rtn;
}

int fat(int size, int posicion, struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,posicion,SEEK_SET);
	//creando estructuras
	struct struct_boot boot;
	struct struct_tabla tabla;
	struct struct_datos datos;
	struct struct_log log;
	//calculando informacion...........
	int m=(int)((size-sizeof(boot))/(sizeof(tabla)+sizeof(datos)+sizeof(log)));
	int rtn=sizeof(boot)+sizeof(tabla)*m + sizeof(datos)*m + sizeof(log)*m;
	//generando informacion
	//boot:
	sprintf(boot.b_nombre_unidad, "%s", tdisco.nombre);
	int salir=0;
	while(salir==0){
		printf("Desea proteger el sistema con contraseña?\n");
		printf("1. Si\n");
		printf("2. No\n");
		int menu=0;
		if (scanf("%d", (&menu)) == 0){
			while (getchar() != '\n'){
				printf("%s","Error, ingrese numero: \n");
				scanf("%d", (&menu));
			}
		}
		if(menu==1){
			printf("%s","Usuario: \n");
			scanf("%s", boot.b_usuario);
			printf("%s","Password: \n");
			scanf("%s", boot.b_password);
			salir=1;
		}else if(menu==2){
			sprintf(boot.b_usuario, "%s", "");
			sprintf(boot.b_password, "%s", "");
			salir=1;
		}else{
			printf("Error\n");
		}
	}
	settime();
	sprintf(boot.b_date_creacion, "%s", fecha);
	sprintf(boot.b_date_ultimo_montaje, "%s", "00/00/0000 00:00");
	sprintf(boot.b_tamano, "%d", size);
	sprintf(boot.b_bloques_count, "%d", 0);
	sprintf(boot.b_tablas_count, "%d", 0);
	sprintf(boot.b_log_count, "%d", 0);
	sprintf(boot.b_bloques_free, "%d", m);
	sprintf(boot.b_tablas_free, "%d", m);
	sprintf(boot.b_log_free, "%d", m);
	sprintf(boot.b_next_tabla_free, "%d", 1);
	sprintf(boot.b_next_bloque_free, "%d", 1);
	sprintf(boot.b_next_log_free, "%d", 1);
	sprintf(boot.b_montajes_count, "%d", 0);
	sprintf(boot.b_ap_bloque_tabla_indexada, "%d", (int)sizeof(boot));
	sprintf(boot.b_ap_bloque_datos, "%d", (int)(sizeof(boot)+m*sizeof(tabla)));
	sprintf(boot.b_ap_log, "%d", (int)(sizeof(boot)+m*sizeof(tabla)+m*sizeof(datos)));
	sprintf(boot.b_size_struct_tabla_indexada, "%d", (int)sizeof(tabla));
	sprintf(boot.b_size_struct_bloque_dato, "%d", (int)sizeof(datos));
	sprintf(boot.b_size_struct_bitacora, "%d", (int)sizeof(log));
	//escribiendo boot
	fwrite(&boot, sizeof(boot), 1, f);
	//escribiendo tabla vacia
	sprintf(tabla.disponible, "%d", 0);
	sprintf(tabla.lista_ap_directo_bloque, "%d", -1);
	sprintf(tabla.lista_nombre_padre, "%s", "");
	for(ifor=0;ifor<m;ifor++)
		fwrite(&tabla, sizeof(tabla), 1, f);
	//escribiendo datos
	sprintf(datos.disponible, "%d", 0);
	sprintf(datos.bd_ap_directo_siguiente, "%d", 0);
	for(ifor=0;ifor<m;ifor++)
		fwrite(&datos, sizeof(datos), 1, f);
	//escribiendo logs
	for(ifor=0;ifor<m;ifor++)
		fwrite(&log, sizeof(log), 1, f);
	//actualizando numero de particiones
	rewind(f);
	fread(&tdisco, sizeof(tdisco), 1, f);
	sprintf(tdisco.particiones, "%d", atoi(tdisco.particiones)+1);
	rewind(f);
	fwrite(&tdisco, sizeof(tdisco), 1, f);
	//cerrando archivo
	fclose(f);
	printf("Particion FAT creada exitosamente!\n");
	return rtn;
}

//creando el gestor de arranque
void arranque(int posicion, int desactivada, char mbr_tipo_sistema_archivos[4],char tipo[9],int activa,int size, struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//creando mbr
	struct struct_mbr mbr;
	sprintf(mbr.mbr_tipo_particion, "%s", tipo);
	sprintf(mbr.mbr_particion_activa, "%d", activa);
	sprintf(mbr.mbr_size_bytes, "%d", size);
	sprintf(mbr.mbr_tipo_sistema_archivos, "%s", mbr_tipo_sistema_archivos);
	sprintf(mbr.mbr_byte_particion, "%d", posicion);
	sprintf(mbr.mbr_byte_particion_desactivada, "%d", desactivada);
	//guardando
	fwrite(&mbr, sizeof(mbr), 1, f);
	//cerrando archivo
	fclose(f);
	printf("mbr creado exitosamente!\n");
}

//editando arranque
void editar_arranque(struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//creando mbr
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	struct struct_mbr mbr_nueva;
	//printf("posicion: %s\n",mbr.mbr_byte_particion);
	//printf("posicion_desactivada: %s\n",mbr.mbr_byte_particion_desactivada);
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		sprintf(mbr_nueva.mbr_tipo_sistema_archivos, "%s", "FAT");
	}else{
		sprintf(mbr_nueva.mbr_tipo_sistema_archivos, "%s", "EXT3");
	}
	sprintf(mbr_nueva.mbr_byte_particion, "%s", mbr.mbr_byte_particion_desactivada);
	sprintf(mbr_nueva.mbr_byte_particion_desactivada, "%s", mbr.mbr_byte_particion);
	sprintf(mbr_nueva.mbr_tipo_particion, "%s", mbr.mbr_tipo_particion);
	sprintf(mbr_nueva.mbr_particion_activa, "%s", mbr.mbr_particion_activa);
	sprintf(mbr_nueva.mbr_size_bytes, "%s", mbr.mbr_size_bytes);
	//printf("posicion: %s\n",mbr_nueva.mbr_byte_particion);
	//printf("posicion_desactivada: %s\n",mbr_nueva.mbr_byte_particion_desactivada);
	//guardando
	fseek(f,sizeof(tdisco),SEEK_SET);
	fwrite(&mbr_nueva, sizeof(mbr_nueva), 1, f);
	//cerrando archivo
	fclose(f);
}

//creando particiones, mostrando opciones

void crear_particion_opciones(struct struct_disco tdisco){
	printf("\n");
	printf("**********************\n");
	printf("CREANDO PARTICION\n");
	printf("DISCO: %s \n",tdisco.nombre);
	printf("**********************\n\n");
	printf("Opciones: \n");
	printf("1. EXT3 - FAT \n");
	printf("2. FAT - EXT3 \n");
	printf("3. Regresar \n");
	int menu=0;
	if (scanf("%d", (&menu)) == 0){
		while (getchar() != '\n'){
			printf("%s","Error, ingrese numero: \n");
			scanf("%d", (&menu));
		}
	}
	//calculando tamaño para cada particion
	struct struct_mbr mbr;
	int size=atoi(tdisco.tamano)*1048576-sizeof(tdisco)-sizeof(mbr);
	size=(int)(size/2);
	int tempo=0;
	switch(menu){
		case 1:
			//creando las particiones, de tamaño size, inician en, estructura disco
			printf("......\n");
			printf("Creando particion EXT3...\n");
			tempo=ext(size, sizeof(tdisco)+sizeof(mbr),tdisco);
			printf("......\n");
			printf("Creando particion FAT...\n");
			fat(size, sizeof(tdisco)+sizeof(mbr)+tempo+512,tdisco);
			//creando mbr
			printf("......\n");
			printf("Configurando gestor de arranque...\n");
			arranque(sizeof(tdisco)+sizeof(mbr), sizeof(tdisco)+sizeof(mbr)+tempo+512,"EXT3","Primaria",1,size, tdisco);
			printf("\nParticiones creadas\n");
		break;
		case 2:
			//creando las particiones, de tamaño size, inician en, estructura disco
			printf("......\n");
			printf("Creando particion FAT...\n");
			tempo=fat(size, sizeof(tdisco)+sizeof(mbr),tdisco);
			printf("......\n");
			printf("Creando particion EXT3...\n");
			ext(size, sizeof(tdisco)+sizeof(mbr)+tempo+512,tdisco);
			//creando mbr
			printf("......\n");
			printf("Configurando gestor de arranque...\n");
			arranque(sizeof(tdisco)+sizeof(mbr), sizeof(tdisco)+sizeof(mbr)+tempo+512,"FAT","Primaria",1,size, tdisco);
			printf("\nParticiones creadas\n");
		break;
		case 3:
			printf("Regresando...\n");
		break;
		default:
			printf("Error\n");
			crear_particion_opciones(tdisco);
		break;
	}
}

//formatear disco
void formatear_particion(struct struct_disco tdisco){
	printf("\n");
	printf("**********************\n");
	printf("FORMATEO DE PARTICIONES\n");
	printf("DISCO: %s \n",tdisco.nombre);
	printf("**********************\n\n");
	printf("Desea formatear las particiones? \n");
	printf("1. Si \n");
	printf("2. No \n");
	int menu=0;
	if (scanf("%d", (&menu)) == 0){
		while (getchar() != '\n'){
			printf("%s","Error, ingrese numero: \n");
			scanf("%d", (&menu));
		}
	}
	//calculando tamaño para cada particion
	struct struct_mbr mbr;
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	fread(&mbr,sizeof(mbr),1,f);
	fclose(f);
	int size=atoi(mbr.mbr_size_bytes);
	int tempo=0;
	switch(menu){
		case 1:
			//creando las particiones, de tamaño size, inician en, estructura disco
			printf("......\n");
			if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
				printf("Formateando particion EXT3...\n");
				tempo=ext(size, sizeof(tdisco)+sizeof(mbr),tdisco);
				printf("......\n");
				printf("Formateando particion FAT...\n");
				fat(size, sizeof(tdisco)+sizeof(mbr)+tempo+512,tdisco);
				//creando mbr
				printf("......\n");
				printf("Configurando gestor de arranque...\n");
				arranque(sizeof(tdisco)+sizeof(mbr), sizeof(tdisco)+sizeof(mbr)+tempo+512,"EXT3","Primaria",1,size, tdisco);
			}else{
				printf("Formateando particion FAT...\n");
				tempo=fat(size, sizeof(tdisco)+sizeof(mbr),tdisco);
				printf("......\n");
				printf("Formateando particion EXT3...\n");
				ext(size, sizeof(tdisco)+sizeof(mbr)+tempo+512,tdisco);
				//creando mbr
				printf("......\n");
				printf("Configurando gestor de arranque...\n");
				arranque(sizeof(tdisco)+sizeof(mbr), sizeof(tdisco)+sizeof(mbr)+tempo+512,"FAT","Primaria",1,size, tdisco);
			}
			printf("\nParticiones formateadas\n");
		break;
		case 2:
			printf("Regresando...\n");
		break;
		default:
			printf("Error\n");
			formatear_particion(tdisco);
		break;
	}
}

//formatear particion
void formatear_disco(struct struct_disco tdisco){
	printf("\n");
	printf("**********************\n");
	printf("FORMATEO DE DISCO\n");
	printf("DISCO: %s \n",tdisco.nombre);
	printf("**********************\n\n");
	printf("Desea formatear el disco? \n");
	printf("1. Si \n");
	printf("2. No \n");
	int menu=0;
	if (scanf("%d", (&menu)) == 0){
		while (getchar() != '\n'){
			printf("%s","Error, ingrese numero: \n");
			scanf("%d", (&menu));
		}
	}
	switch(menu){
		case 1:
			set_disco(tdisco.nombre);
			FILE *f = fopen (directorio, "w+b");
			for(ifor=0;ifor<atoi(tdisco.tamano)*1024;ifor++)
				fwrite (buffer, sizeof(buffer), 1024, f);
			//guardando informacion del disco
			rewind(f);
			sprintf(tdisco.particiones,"%s","0");
			fwrite(&tdisco,sizeof(tdisco),1,f);
			fclose(f);
			printf("Disco %s formateado exitosamente\n", tdisco.nombre);
		break;
		case 2:
			printf("Regresando...\n");
		break;
		default:
			printf("Error\n");
			formatear_disco(tdisco);
		break;
	}
}

//mostrar mbr
void mostrar_mbr(struct struct_disco tdisco){
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	fclose(f);
	//mostrando informacion
	printf("\n");
	printf("**********************\n");
	printf("INFORMACION MBR \n");
	printf("**********************\n");
	printf("\nPARTICION ACTIVA:\n");
	printf("Byte de inicio de particion:%s\n",mbr.mbr_byte_particion);
	printf("Sistema de archivos:%s\n",mbr.mbr_tipo_sistema_archivos);
	printf("Tipo de particion:%s\n",mbr.mbr_tipo_particion);
	printf("Activa:%s\n",mbr.mbr_particion_activa);
	printf("Tamaño en Bytes:%s\n",mbr.mbr_size_bytes);
	printf("\nPARTICION RAID:\n");
	printf("Byte de inicio de particion:%s\n",mbr.mbr_byte_particion_desactivada);
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0)
		printf("Sistema de archivos:FAT\n");
	else
		printf("Sistema de archivos:EXT3\n");
	printf("Tipo de particion:%s\n",mbr.mbr_tipo_particion);
	printf("Activa:0\n");
	printf("Tamaño en Bytes:%s\n",mbr.mbr_size_bytes);
	printf("\nPresione cualquier tecla para continuar\n");
	//salida
	char c;
	scanf("%c",&c);
	getchar();
}

//mostrar mbr
void mostrar_datos_sistema(struct struct_disco tdisco){
	//mostrando informacion
	printf("\n");
	printf("**********************\n");
	printf("DATOS ACTUALES DEL SISTEMA: \n");
	printf("**********************\n");
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "rb+");
	fseek(f,sizeof(tdisco),SEEK_SET);
	//leyendo mbr
	struct struct_mbr mbr;
	fread(&mbr, sizeof(mbr), 1, f);
	int address=atoi(mbr.mbr_byte_particion);
	fseek(f, address,SEEK_SET);
	if(strcmp(mbr.mbr_tipo_sistema_archivos,"EXT3")==0){
		printf("\nSuperbloque:\n");
		struct struct_superbloque superbloque;
		fread(&superbloque, sizeof(superbloque), 1, f);
		//--
		printf("Cantidad de inodos:%s\n",superbloque.sb_numero_inodos);
		printf("Cantidad de bloques:%s\n",superbloque.sb_numero_bloques);
		printf("Cantidad de logs:%s\n",superbloque.sb_numero_log);
		printf("Tamaño de cada bloque (Bytes):%s\n",superbloque.sb_tamanio_bloque);
		printf("Firma del disco:%s\n",superbloque.sb_numero_magico);
		printf("Bloques libres:%s\n",superbloque.sb_bloques_freee);
		printf("Inodos libres:%s\n",superbloque.sb_inodos_free);
		printf("Logs libres:%s\n",superbloque.sb_log_free);
		printf("Fecha de creacion del sistema:%s\n",superbloque.sb_date_creacion);
		printf("Ultima fecha de montaje:%s\n",superbloque.sb_mount_time);
		printf("Ultima fecha desmontaje:%s\n",superbloque.sb_write_time);
		printf("Numero de montajes:%s\n",superbloque.sb_mount_count);
		printf("Inicio de bitacora:%s\n",superbloque.sb_ap_bitacora);
		printf("Inicio de inodos:%s\n",superbloque.sb_first_inodo);
		printf("Inicio de bloques:%s\n",superbloque.sb_first_bloque);
		printf("Bitmap, siguiente inodo libre:%s\n",superbloque.sb_fist_free_bitmapinodo);
		printf("Bitmap, siguiente bloque libre:%s\n",superbloque.sb_first_free_bitmapbloque);
		printf("Siguiente log libre:%d\n",Bitacora_nextfree(tdisco,1));
		//--
	}else{
		printf("\nBoot:\n");
		struct struct_boot boot;
		fread(&boot, sizeof(boot), 1, f);
		//--
		printf("Raiz:%s\n",boot.b_nombre_unidad);
		printf("Usuario:%s\n",boot.b_usuario);
		printf("Password:%s\n",boot.b_password);
		printf("Tamaño en bytes del sistema:%s\n",boot.b_tamano);
		printf("Cantidad de tablas usadas:%s\n",boot.b_tablas_count);
		printf("Cantidad de bloques usados:%s\n",boot.b_bloques_count);
		printf("Cantidad de logs usados:%s\n",boot.b_log_count);
		printf("Siguiente tabla libre:%s\n",boot.b_next_tabla_free);
		printf("Siguiente bloque libre:%s\n",boot.b_next_bloque_free);
		printf("Siguiente log libre:%s\n",boot.b_next_log_free);
		printf("Cantidad de tablas libres:%s\n",boot.b_tablas_free);
		printf("Cantidad de bloques libres:%s\n",boot.b_bloques_free);
		printf("Cantidad de log libres:%s\n",boot.b_log_free);
		printf("Fecha de creacion del sistema:%s\n",boot.b_date_creacion);
		printf("Fecha de ultimo montaje:%s\n",boot.b_date_ultimo_montaje);
		printf("Contador de montajes:%s\n",boot.b_montajes_count);
		printf("Inicio de tablas:%s\n",boot.b_ap_bloque_tabla_indexada);
		printf("Inicio de bloques:%s\n",boot.b_ap_bloque_datos);
		printf("Inicio de log:%s\n",boot.b_ap_log);
		printf("Tamaño de tabla en bytes:%s\n",boot.b_size_struct_tabla_indexada);
		printf("Tamaño de bloque en bytes:%s\n",boot.b_size_struct_bloque_dato);
		printf("Tamaño de log en bytes:%d\n",Bitacora_nextfree(tdisco,1));
		//--
	}
	fclose(f);
	
	printf("\nPresione cualquier tecla para continuar\n");
	//salida
	char c;
	scanf("%c",&c);
	getchar();
}

//entrar al disco

void entrar_al_disco(char unidad[640]){
	//leyendo unidad binaria
	set_disco(unidad);
	FILE *f = fopen (directorio, "rb+");
	printf("\n");
	printf("**********************\n");
	printf("DISCO: %s \n",unidad);
	printf("**********************\n");
	//mostrando la informacion del disco duro
	struct struct_disco tdisco;
	fread(&tdisco,sizeof(tdisco),1,f);
	fclose(f);
	printf("tamaño: %s MB \n", tdisco.tamano);
	printf("particiones: %s\n\n", tdisco.particiones);
	printf("Opciones de disco:\n");
	printf("1. Montar particion primaria\n");
	printf("2. Crear particiones\n");
	printf("3. Formatear particion\n");
	printf("4. Formatear disco\n");
	printf("5. Desactivar particion, iniciar con desactivada\n");
	printf("6. Reportes\n");
	printf("7. Mostrar mbr\n");
	printf("8. Ver datos actuales del sistema\n");
	printf("9. Desmontar disco duro\n");
	int menu=0;
    if (scanf("%d", (&menu)) == 0){
		while (getchar() != '\n'){
			printf("Error, ingrese numero: \n");
			scanf("%d", (&menu));
		}
	}
    switch(menu){
    	case 1:
    		if(atoi(tdisco.particiones)==0)
				printf("\n!!!!!!!!!!!!!!!!!!!!!\nEl disco duro no contiene particiones primarias \n!!!!!!!!!!!!!!!!!!!!!\n\n");
    		else
				montar_particion(tdisco);
			entrar_al_disco(unidad);
    	break;
    	case 2:
			if(atoi(tdisco.particiones)==0)
				crear_particion_opciones(tdisco);
			else
				printf("\n!!!!!!!!!!!!!!!!!!!!!\nEl disco duro ya contiene 2 particiones primarias \nFormatear para crear nuevas\n!!!!!!!!!!!!!!!!!!!!!\n\n");
    		entrar_al_disco(unidad);
    	break;
    	case 3:
			formatear_particion(tdisco);
    		entrar_al_disco(unidad);
    	break;
    	case 4:
    		formatear_disco(tdisco);
    		entrar_al_disco(unidad);
    	break;
    	case 5:
    		printf("Editando gestor de arranque...\n");
    		editar_arranque(tdisco);
    		printf("Finalizado...\n");
    		entrar_al_disco(unidad);
    	break;
    	case 6:
    		reportes(tdisco);
    		entrar_al_disco(unidad);
    	break;
    	case 7:
    		mostrar_mbr(tdisco);
    		entrar_al_disco(unidad);
    	break;
    	case 8:
    		mostrar_datos_sistema(tdisco);
    		entrar_al_disco(unidad);
    	break;
    	case 9:
    		printf("Desmontando disco...\n");
    	break;
    	default:
    		printf("Error\n");
    		entrar_al_disco(unidad);
    	break;	
    }
}

//listar discos

void listar_discos(){
	printf("\n");
	printf("**********************\n");
	printf("LISTA DE DISCOS\n");
	printf("**********************\n");
	d= opendir(sistema);
	int discos=0;
	while ((di=readdir(d)) != NULL ){
		if((strcmp(di->d_name, ".")!=0) & (strcmp(di->d_name, "..")!=0)){
			if(discos==0)
				printf("Seleccione el disco duro a montar:\n");
			discos++;
    		printf ( "%d. %s\n" , discos, di->d_name );
    	}
    }
    int regresar=0;
    if(discos==0){
    	printf("¡No ha creado ningun disco en el sistema!\n");
    }else{
    	discos++;
    	printf("%d. Regresar\n", discos);
    	int menu=0;
    	if (scanf("%d", (&menu)) == 0){
			while (getchar() != '\n'){
				printf("Error, ingrese numero: \n");
				scanf("%d", (&menu));
			}
		}
    	if((menu>0) & (menu<discos)){
    		//para entrar al disco
    		closedir(d);
    		d= opendir(sistema);
    		discos=0;
    		int out=0;
    		while (((di=readdir(d)) != NULL) & (out==0) ){
				if((strcmp(di->d_name, ".")!=0) & (strcmp(di->d_name, "..")!=0)){
					discos++;
					if(discos==menu){
						entrar_al_disco(di->d_name);
						out=1;
					}
				}
			}
    		regresar=1;
    	}else if(menu==discos){
    		printf("Regresando...\n");
    	}else{
    		printf("Error\n");
    		regresar=1;
    	}
    }	
	closedir(d);
	if(regresar==1)
		listar_discos();
}

//menu crear disco

void crear_disco(){
	struct struct_disco tdisco;
	printf("\n");
	printf("**********************\n");
	printf("CREAR DISCO\n");
	printf("**********************\n");
	printf("nombre (max 50 caracteres):\n");
	scanf("%s",tdisco.nombre);
	printf("tamaño en MB (max 7 numeros, multiplo de 4):\n");
	int tamano=0;
	int repetir=0;
	while(repetir==0){
		if (scanf("%d", (&tamano)) == 0){
			while (getchar() != '\n'){
				printf("Error, ingrese numero:.. \n");
				scanf("%d", (&tamano));
			}
		}
		while(tamano>128){
			printf("¡tamaño mayor a 128mb!\n");
			printf("tamaño en MB (max 7 numeros):\n");
			if (scanf("%d", (&tamano)) == 0){
				while (getchar() != '\n'){
					printf("Error, ingrese numero:.. \n");
					scanf("%d", (&tamano));
				}
			}
		}
		if((tamano%4)==0)
			repetir=1;
		else
			printf("Error ingrese un multiplo de 4.. \n");
	}
	sprintf(tdisco.tamano, "%d", tamano);
	sprintf(tdisco.particiones, "%d", 0);
	sprintf(tdisco.puntero, "%d", (int)sizeof(tdisco));
	printf("Creando disco...\n");
	//creando el disco
	set_disco(tdisco.nombre);
	FILE *f = fopen (directorio, "w+b");
	for(ifor=0;ifor<tamano*1024;ifor++)
		fwrite (buffer, sizeof(buffer), 1024, f);
	//guardando informacion del disco
	rewind(f);
	fwrite(&tdisco,sizeof(tdisco),1,f);
	fclose(f);
	printf("Disco %s creado exitosamente\n", tdisco.nombre);
}

//menu principal

void menu_principal(){
	int menu=0;
	printf("\n");
   	printf("::::::::::::::::::::::::::::::::: \n");
   	printf("Jose 72826 OS \n");
   	printf("::::::::::::::::::::::::::::::::: \n");
	printf("1. Crear Disco \n");
	printf("2. Listar Discos \n");
	printf("3. Salir \n");
	if (scanf("%d", (&menu)) == 0){
		while (getchar() != '\n'){
			printf("Error, ingrese numero: \n");
			scanf("%d", (&menu));
		}
	}
	switch(menu){
		case 1:
			crear_disco();
			menu_principal();
		break;
		case 2:
			listar_discos();
			menu_principal();
		break;
		case 3:
			printf("\n");
			printf("saliendo.. \n");
		break;
		default:
			printf("Error.. \n");
			menu_principal();
		break;
	}	
}

//menu inicial

int main(int argc, char **argv){
	//verifica si se tienen particiones
	inicializacion();
	//llama al menu principal
	menu_principal();
	//termino el programa
	printf("\n");
	printf("::::::::::::::::::::::::::::::::: \n");
	printf("\n");
	printf("\n");
   	printf("Jose 72826 OS \n");
   	printf("\n");
   	printf("Apagando el sistema... \n");
   	printf("\n");
   	printf("\n");
   	printf("::::::::::::::::::::::::::::::::: \n");
	return 0;
}

